@@ -22,11 +22,11 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
-    along with JSXGraph.  If not, see <http://www.gnu.org/licenses/>.
+    along with JSXGraph.  If not, see <https://www.gnu.org/licenses/>.
 '''
 import sys
 import os
-import urllib
+import urllib.request, urllib.parse, urllib.error
 import base64
 import zlib
 
@@ -40,6 +40,6 @@ if __name__ == '__main__':
         sys.exit(0) 
     f = open(filename, "r")
     text = f.read()
-    text = urllib.unquote(zlib.decompress(base64.b64decode(text)))
-    print text
+    text = urllib.parse.unquote(zlib.decompress(base64.b64decode(text)))
+    print(text, end="")
     
