@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Aaron Fenyes,
         Carsten Miller,
@@ -33,6 +33,8 @@ import JXG from "../jxg.js";
 import Const from "../base/constants.js";
 import Type from "../utils/type.js";
 import Mat from "../math/math.js";
+import Stat from "../math/statistics.js";
+import Geometry from "../math/geometry.js";
 
 /**
  * A sphere consists of all points with a given distance from a given point.
@@ -67,8 +69,8 @@ JXG.Sphere3D = function (view, method, par1, par2, attributes) {
      * <ul><li><b><code>'twoPoints'</code></b> &ndash; The sphere is defined by its center and a point on the sphere.</li>
      * <li><b><code>'pointRadius'</code></b> &ndash; The sphere is defined by its center and its radius in user units.</li></ul>
      * @type String
-     * @see #center
-     * @see #point2
+     * @see JXG.Sphere3D#center
+     * @see JXG.Sphere3D#point2
      */
     this.method = method;
 
@@ -81,7 +83,7 @@ JXG.Sphere3D = function (view, method, par1, par2, attributes) {
     /**
      * A point on the sphere; only set if the construction method is 'twoPoints'. Do not set this parameter directly, as that will break JSXGraph's update system.
      * @type JXG.Point3D
-     * @see #method
+     * @see JXG.Sphere3D#method
      */
     this.point2 = null;
 
@@ -96,6 +98,7 @@ JXG.Sphere3D = function (view, method, par1, par2, attributes) {
     /**
      * Elements supporting the 2D representation.
      * @type Array
+     * @private
      */
     this.aux2D = [];
 
@@ -144,6 +147,25 @@ Type.copyPrototypeMethods(JXG.Sphere3D, JXG.GeometryElement3D, "constructor3D");
 JXG.extend(
     JXG.Sphere3D.prototype,
     /** @lends JXG.Sphere3D.prototype */ {
+
+        X: function(u, v) {
+            var r = this.Radius();
+            return r * Math.sin(u) * Math.cos(v);
+        },
+
+        Y: function(u, v) {
+            var r = this.Radius();
+            return r * Math.sin(u) * Math.sin(v);
+        },
+
+        Z: function(u, v) {
+            var r = this.Radius();
+            return r * Math.cos(u);
+        },
+
+        range_u: [0, 2 * Math.PI],
+        range_v: [0, Math.PI],
+
         update: function () {
             if (this.projectionType !== this.view.projectionType) {
                 this.rebuildProjection();
@@ -181,7 +203,7 @@ JXG.extend(
             }
 
             if (this.method === "twoPoints") {
-                if (this.center.isIllDefined() || this.point2.isIllDefined()) {
+                if (!this.center.testIfFinite() || !this.point2.testIfFinite()) {
                     return NaN;
                 }
 
@@ -231,18 +253,30 @@ JXG.extend(
                     p = view.worldToFocal(that.center.coords, false),
                     distOffAxis = Mat.hypot(p[0], p[1]),
                     cam = view.boxToCam,
-                    inward = [
-                        -(p[0] * cam[1][1] + p[1] * cam[2][1]) / distOffAxis,
-                        -(p[0] * cam[1][2] + p[1] * cam[2][2]) / distOffAxis,
-                        -(p[0] * cam[1][3] + p[1] * cam[2][3]) / distOffAxis
-                    ],
                     r = that.Radius(),
                     angleOffAxis = Math.atan(-distOffAxis / p[2]),
                     steepness = Math.acos(r / Mat.norm(p)),
                     lean = angleOffAxis + steepness,
                     cos_lean = Math.cos(lean),
-                    sin_lean = Math.sin(lean);
+                    sin_lean = Math.sin(lean),
+                    inward;
 
+                if (distOffAxis > 1e-8) {
+                    // if the center of the sphere isn't too close to the camera
+                    // axis, find the direction in plane of the screen that
+                    // points from the center of the sphere toward the camera
+                    // axis
+                    inward = [
+                        -(p[0] * cam[1][1] + p[1] * cam[2][1]) / distOffAxis,
+                        -(p[0] * cam[1][2] + p[1] * cam[2][2]) / distOffAxis,
+                        -(p[0] * cam[1][3] + p[1] * cam[2][3]) / distOffAxis
+                    ];
+                } else {
+                    // if the center of the sphere is very close to the camera
+                    // axis, choose an arbitrary unit vector in the plane of the
+                    // screen
+                    inward = [cam[1][1], cam[1][2], cam[1][3]];
+                }
                 return view.project3DTo2D([
                     that.center.X() + r * (sin_lean * inward[0] + cos_lean * cam[3][1]),
                     that.center.Y() + r * (sin_lean * inward[1] + cos_lean * cam[3][2]),
@@ -251,7 +285,7 @@ JXG.extend(
             };
         },
 
-        buildCentralProjection: function () {
+        buildCentralProjection: function (attr) {
             var view = this.view,
                 auxStyle = { visible: false, withLabel: false },
                 frontFocus = view.create('point', this.focusFn(-1), auxStyle),
@@ -259,16 +293,16 @@ JXG.extend(
                 innerVertex = view.create('point', this.innerVertexFn(view), auxStyle);
 
             this.aux2D = [frontFocus, backFocus, innerVertex];
-            this.element2D = view.create('ellipse', this.aux2D, this.visProp);
+            this.element2D = view.create('ellipse', this.aux2D, attr === undefined ? this.visProp : attr);
         },
 
-        buildParallelProjection: function () {
+        buildParallelProjection: function (attr) {
             // The parallel projection of a sphere is a circle
             var that = this,
-                center2d = function () {
-                    var c3d = [1, that.center.X(), that.center.Y(), that.center.Z()];
-                    return that.view.project3DTo2D(c3d);
-                },
+                // center2d = function () {
+                //     var c3d = [1, that.center.X(), that.center.Y(), that.center.Z()];
+                //     return that.view.project3DTo2D(c3d);
+                // },
                 radius2d = function () {
                     var boxSize = that.view.bbox3D[0][1] - that.view.bbox3D[0][0];
                     return that.Radius() * that.view.size[0] / boxSize;
@@ -277,14 +311,15 @@ JXG.extend(
             this.aux2D = [];
             this.element2D = this.view.create(
                 'circle',
-                [center2d, radius2d],
-                this.visProp
+                // [center2d, radius2d],
+                [that.center.element2D, radius2d],
+                attr === undefined ? this.visProp : attr
             );
         },
 
         // replace our 2D representation with a new one that's consistent with
         // the view's current projection type
-        rebuildProjection: function () {
+        rebuildProjection: function (attr) {
             var i;
 
             // remove the old 2D representation from the scene tree
@@ -302,29 +337,76 @@ JXG.extend(
             // `this.aux2D`
             this.projectionType = this.view.projectionType;
             if (this.projectionType === 'central') {
-                this.buildCentralProjection();
+                this.buildCentralProjection(attr);
             } else {
-                this.buildParallelProjection();
+                this.buildParallelProjection(attr);
             }
 
             // attach the new 2D representation to the scene tree
             this.addChild(this.element2D);
             this.inherits.push(this.element2D);
             this.element2D.view = this.view;
+        },
+
+        // Already documented in element3d.js
+        projectCoords: function(p, params) {
+            var r = this.Radius(),
+                pp = [1].concat(p),
+                c = this.center.coords,
+                d = Geometry.distance(c, pp, 4),
+                v = Stat.subtract(pp, c);
+
+            if (d === 0) {
+                // p is at the center, take an arbitrary point on sphere
+                params[0] = 0;
+                params[1] = 0;
+                return [1, r, 0, 0];
+            }
+            if (r === 0) {
+                params[0] = 0;
+                params[1] = 0;
+                return this.center.coords;
+            }
+
+            d = r / d;
+            v[0] = 1;
+            v[1] *= d;
+            v[2] *= d;
+            v[3] *= d;
+
+            // Preimage of the new position
+            params[1] = Math.atan2(v[2], v[1]);
+            params[1] += (params[1] < 0) ? Math.PI : 0;
+            if (params[1] !== 0) {
+                params[0] = Math.atan2(v[2], v[3] * Math.sin(params[1]));
+            } else {
+                params[0] = Math.atan2(v[1], v[3] * Math.cos(params[1]));
+            }
+            params[0] += (params[0] < 0) ? 2 * Math.PI : 0;
+
+            return v;
         }
+
+        // projectScreenCoords: function (pScr, params) {
+        //     if (params.length === 0) {
+        //         params.unshift(
+        //             0.5 * (this.range_u[0] + this.range_u[1]),
+        //             0.5 * (this.range_v[0] + this.range_v[1])
+        //         );
+        //     }
+        //     return Geometry.projectScreenCoordsToParametric(pScr, this, params);
+        // }
     }
 );
 
 /**
- * @class This element is used to provide a constructor for a sphere.
- *
- * @pseudo
- * @description
+ * @class A sphere in a 3D view.
  * A sphere consists of all points with a given distance from a given point.
  * The given point is called the center, and the given distance is called the radius.
  * A sphere can be constructed by providing a center and a point on the sphere or a center and a radius (given as a number or function).
  * If the radius is a negative value, its absolute value is taken.
  *
+ * @pseudo
  * @name Sphere3D
  * @augments JXG.Sphere3D
  * @constructor
@@ -417,6 +499,69 @@ JXG.extend(
  *
  * </script><pre>
  *
+ * @example
+ *     // Glider on sphere
+ *     var view = board.create(
+ *         'view3d',
+ *         [[-6, -3], [8, 8],
+ *         [[-3, 3], [-3, 3], [-3, 3]]],
+ *         {
+ *             depthOrder: {
+ *                 enabled: true
+ *             },
+ *             projection: 'central',
+ *             xPlaneRear: {fillOpacity: 0.2, gradient: null},
+ *             yPlaneRear: {fillOpacity: 0.2, gradient: null},
+ *             zPlaneRear: {fillOpacity: 0.2, gradient: null}
+ *         }
+ *     );
+ *
+ *     // Two points
+ *     var center = view.create('point3d', [0, 0, 0], {withLabel: false, size: 2});
+ *     var point = view.create('point3d', [2, 0, 0], {withLabel: false, size: 2});
+ *
+ *     // Sphere
+ *     var sphere = view.create('sphere3d', [center, point], {fillOpacity: 0.8});
+ *
+ *     // Glider on sphere
+ *     var glide = view.create('point3d', [2, 2, 0, sphere], {withLabel: false, color: 'red', size: 4});
+ *     var l1 = view.create('line3d', [glide, center], { strokeWidth: 2, dash: 2 });
+ *
+ * </pre><div id="JXG672fe3c7-e6fd-48e0-9a24-22f51f2dfa71" class="jxgbox" style="width: 300px; height: 300px;"></div>
+ * <script type="text/javascript">
+ *     (function() {
+ *         var board = JXG.JSXGraph.initBoard('JXG672fe3c7-e6fd-48e0-9a24-22f51f2dfa71',
+ *             {boundingbox: [-8, 8, 8,-8], axis: false, showcopyright: false, shownavigation: false});
+ *         var view = board.create(
+ *             'view3d',
+ *             [[-6, -3], [8, 8],
+ *             [[-3, 3], [-3, 3], [-3, 3]]],
+ *             {
+ *                 depthOrder: {
+ *                     enabled: true
+ *                 },
+ *                 projection: 'central',
+ *                 xPlaneRear: {fillOpacity: 0.2, gradient: null},
+ *                 yPlaneRear: {fillOpacity: 0.2, gradient: null},
+ *                 zPlaneRear: {fillOpacity: 0.2, gradient: null}
+ *             }
+ *         );
+ *
+ *         // Two points
+ *         var center = view.create('point3d', [0, 0, 0], {withLabel: false, size: 2});
+ *         var point = view.create('point3d', [2, 0, 0], {withLabel: false, size: 2});
+ *
+ *         // Sphere
+ *         var sphere = view.create('sphere3d', [center, point], {fillOpacity: 0.8});
+ *
+ *         // Glider on sphere
+ *         var glide = view.create('point3d', [2, 2, 0, sphere], {withLabel: false, color: 'red', size: 4});
+ *         var l1 = view.create('line3d', [glide, center], { strokeWidth: 2, dash: 2 });
+ *
+ *     })();
+ *
+ * </script><pre>
+ *
  */
 JXG.createSphere3D = function (board, parents, attributes) {
     //   parents[0]: view
@@ -428,7 +573,6 @@ JXG.createSphere3D = function (board, parents, attributes) {
         el, i;
 
     attr = Type.copyAttributes(attributes, board.options, 'sphere3d');
-
     p = [];
     for (i = 1; i < parents.length; i++) {
         if (Type.isPointType3D(board, parents[i])) {
@@ -452,15 +596,18 @@ JXG.createSphere3D = function (board, parents, attributes) {
     if (Type.isPoint3D(p[0]) && Type.isPoint3D(p[1])) {
         // Point/Point
         el = new JXG.Sphere3D(view, "twoPoints", p[0], p[1], attr);
+
+        /////////////// nothing in docs suggest you can use [number, pointType]
+        // } else if (
+        //     (Type.isNumber(p[0]) || Type.isFunction(p[0]) || Type.isString(p[0])) &&
+        //     Type.isPoint3D(p[1])
+        // ) {
+        //     // Number/Point
+        //     el = new JXG.Sphere3D(view, "pointRadius", p[1], p[0], attr);
+
     } else if (
-        (Type.isNumber(p[0]) || Type.isFunction(p[0]) || Type.isString(p[0])) &&
-        Type.isPoint3D(p[1])
-    ) {
-        // Number/Point
-        el = new JXG.Sphere3D(view, "pointRadius", p[1], p[0], attr);
-    } else if (
-        (Type.isNumber(p[1]) || Type.isFunction(p[1]) || Type.isString(p[1])) &&
-        Type.isPoint3D(p[0])
+        Type.isPoint3D(p[0]) &&
+        (Type.isNumber(p[1]) || Type.isFunction(p[1]) || Type.isString(p[1]))
     ) {
         // Point/Number
         el = new JXG.Sphere3D(view, "pointRadius", p[0], p[1], attr);
@@ -475,10 +622,16 @@ JXG.createSphere3D = function (board, parents, attributes) {
         );
     }
 
-    // build a 2D representation, and attach it to the scene tree, and update it
+    // Build a 2D representation, and attach it to the scene tree, and update it
     // to the correct initial state
-    el.rebuildProjection();
-    el.element2D.prepareUpdate().update().updateRenderer();
+    // Here, element2D is created.
+    attr = el.setAttr2D(attr);
+    el.rebuildProjection(attr);
+
+    el.element2D.prepareUpdate().update();
+    if (!board.isSuspendedUpdate) {
+        el.element2D.updateVisibility().updateRenderer();
+    }
 
     return el;
 };
