@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -226,13 +226,8 @@ JXG.extend(
          * @returns {Array}    Array of JXG polygons defining the bars
          */
         drawBar: function (board, x, y, attributes) {
-            var i,
-                text,
-                w,
-                xp0,
-                xp1,
-                xp2,
-                yp,
+            var i, text, w,
+                xp0, xp1, xp2, yp,
                 colors,
                 pols = [],
                 p = [],
@@ -296,13 +291,11 @@ JXG.extend(
                     p[3] = board.create("point", [0, xp2], hiddenPoint);
 
                     if (Type.exists(attr.labels) && Type.exists(attr.labels[i])) {
+                        attrSub.anchorX = function (self) {
+                            return self.X() >= 0 ? "left" : "right";
+                        };
                         attrSub.anchorY = "middle";
                         text = board.create("text", [yp, xp1, attr.labels[i]], attrSub);
-                        text.visProp.anchorx = (function (txt) {
-                            return function () {
-                                return txt.X() >= 0 ? "left" : "right";
-                            };
-                        })(text);
                     }
                 } else {
                     // vertical bars
@@ -313,14 +306,10 @@ JXG.extend(
 
                     if (Type.exists(attr.labels) && Type.exists(attr.labels[i])) {
                         attrSub.anchorX = "middle";
-
+                        attrSub.anchorY = function (self) {
+                            return self.Y() >= 0 ? "bottom" : "top";
+                        };
                         text = board.create("text", [xp1, yp, attr.labels[i]], attrSub);
-
-                        text.visProp.anchory = (function (txt) {
-                            return function () {
-                                return txt.Y() >= 0 ? "bottom" : "top";
-                            };
-                        })(text);
                     }
                 }
 
@@ -332,6 +321,7 @@ JXG.extend(
                 pols[i] = board.create("polygon", p, attr);
                 if (Type.exists(attr.labels) && Type.exists(attr.labels[i])) {
                     pols[i].text = text;
+                    pols[i].addChild(text);
                 }
             }
 
@@ -427,7 +417,7 @@ JXG.extend(
 
                     if (Type.exists(this.label)) {
                         this.label.rendNode.style.fontSize =
-                            s * Type.evaluate(this.label.visProp.fontsize) + "px";
+                            s * this.label.evalVisProp('fontsize') + "px";
                         this.label.fullUpdate();
                     }
 
@@ -605,11 +595,8 @@ JXG.extend(
                 data,
                 len = parents.length,
                 get_anchor = function () {
-                    var x1,
-                        x2,
-                        y1,
-                        y2,
-                        relCoords = Type.evaluate(this.visProp.label.offset).slice(0);
+                    var x1, x2, y1, y2,
+                        relCoords = this.evalVisProp('label.offset).slice(0');
 
                     x1 = this.point1.X();
                     x2 = this.point2.X();
@@ -965,7 +952,7 @@ JXG.extend(
 );
 
 /**
- * @class Constructor for a chart.
+ * @class Various types of charts for data visualization.
  * @pseudo
  * @name Chart
  * @augments JXG.Chart
@@ -1334,14 +1321,13 @@ JXG.registerElement("chart", JXG.createChart);
 
 /**
  * Legend for chart
- * TODO
  *
  * The Legend class is a basic class for legends.
- * @class Creates a new Lgend object. Do not use this constructor to create a legend.
+ * @class Creates a new Legend object. Do not use this constructor to create a legend.
  * Use {@link JXG.Board#create} with type {@link Legend} instead.
  * <p>
  * The legend object consists of segements with labels. These lines can be
- * access with the property "lines" of the element.
+ * accessed with the property "lines" of the element.
  * @constructor
  * @augments JXG.GeometryElement
  * @param {String|JXG.Board} board The board the new legend is drawn on.
@@ -1361,12 +1347,14 @@ JXG.Legend = function (board, coords, attributes) {
     this.myAtts = {};
     this.label_array = attr.labelarray || attr.labels;
     this.color_array = attr.colorarray || attr.colors;
+    this.opacy_array = attr.strokeopacity || [1];
     this.lines = [];
     this.myAtts.strokewidth = attr.strokewidth || 5;
     this.myAtts.straightfirst = false;
     this.myAtts.straightlast = false;
     this.myAtts.withlabel = true;
     this.myAtts.fixed = true;
+    this.myAtts.frozen = attr.frozen || false ;
     this.style = attr.legendstyle || attr.style;
 
     if (this.style === "vertical") {
@@ -1374,6 +1362,9 @@ JXG.Legend = function (board, coords, attributes) {
     } else {
         throw new Error("JSXGraph: Unknown legend style: " + this.style);
     }
+
+    this.id = this.board.setId(this, "Leg");
+
 };
 
 JXG.Legend.prototype = new GeometryElement();
@@ -1402,6 +1393,8 @@ JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
         this.myAtts.name = this.label_array[i];
         this.myAtts.strokecolor = this.color_array[i % this.color_array.length];
         this.myAtts.highlightstrokecolor = this.color_array[i % this.color_array.length];
+        this.myAtts.strokeopacity = this.opacy_array[i % this.opacy_array.length];
+        this.myAtts.highlightstrokeopacity = this.opacy_array[i % this.opacy_array.length];
         this.myAtts.label = {
             offset: [10, 0],
             strokeColor: this.color_array[i % this.color_array.length],
@@ -1417,17 +1410,23 @@ JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
             this.myAtts
         );
 
+        if (this.myAtts.frozen){
+            this.lines[i].setAttribute({ point1: { frozen: true }, point2: { frozen: true } });
+        }
+
         this.lines[i].getLabelAnchor = getLabelAnchor;
         this.lines[i]
             .prepareUpdate()
             .update()
-            .updateVisibility(Type.evaluate(this.lines[i].visProp.visible))
+            .updateVisibility(this.lines[i].evalVisProp('visible'))
             .updateRenderer();
+
+        this.addChild(this.lines[i]);
     }
 };
 
 /**
- * @class This element is used to provide a constructor for a chart legend.
+ * @class Creates a legend for a chart element.
  * Parameter is a pair of coordinates. The label names and  the label colors are
  * supplied in the attributes:
  * <ul>
@@ -1435,8 +1434,11 @@ JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
  * <li> labelArray (Array): alternative array for label names (has precedence over 'labels')
  * <li> colors (Array): array of color values
  * <li> colorArray (Array): alternative array for color values (has precedence over 'colors')
+ * <li> opacities (Array): opacity of a line in the legend
  * <li> legendStyle or style: at the time being only 'vertical' is supported.
- * <li> rowHeight.
+ * <li> rowHeight: height of an entry in the legend (in px)
+ * <li> linelenght: length of a line in the legend (measured in the coordinate system)
+ * <li> frozen (Boolean, false):
  * </ul>
  *
  * @pseudo
@@ -1473,6 +1475,74 @@ JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
  *
  * </script><pre>
  *
+ * @example
+ *   var inputFun, cf = [], cf2 = [], niveaunum,
+ *     niveauline = [], niveauopac = [],legend;
+ *
+ *   inputFun = "x^2/2-2*x*y+y^2/2";
+ *   niveauline = [-3,-2,-1,-0.5, 0, 1,2,3];
+ *   niveaunum = niveauline.length;
+ *   for (let i = 0; JXG.Math.lt(i, niveaunum); i++) {
+ *     let niveaui = niveauline[i];
+ *     niveauopac.push(((i + 1) / (niveaunum + 1)));
+ *     cf.push(board.create("implicitcurve", [
+ *       inputFun + "-(" + niveaui.toFixed(2) + ")", [-2, 2], [-2, 2]], {
+ *       strokeWidth: 2,
+ *       strokeColor: JXG.palette.red,
+ *       strokeOpacity: niveauopac[i],
+ *       needsRegularUpdate: false,
+ *       name: "niveau"+i,
+ *       visible: true
+ *     }));
+ *   }
+ *   legend = board.create('legend', [-1.75, 1.75], {
+ *     labels: niveauline,
+ *     colors: [cf[0].visProp.strokecolor],
+ *     strokeOpacity: niveauopac,
+ *     linelength: 0.2,
+ *     frozen:true
+ *   }
+ *   );
+ *
+ *
+ * </pre><div id="JXG079fce93-07b9-426f-a267-ab9c1253e435" class="jxgbox" style="width: 300px; height: 300px;"></div>
+ * <script type="text/javascript">
+ *     (function() {
+ *         var board = JXG.JSXGraph.initBoard('JXG079fce93-07b9-426f-a267-ab9c1253e435',
+ *             {boundingbox: [-2, 2, 2, -2], axis: true, showcopyright: false, shownavigation: false});
+ *       var board, inputFun, cf = [], cf2 = [], niveaunum,
+ *         niveauline = [], niveauopac = [],legend;
+ *
+ *       inputFun = "x^2/2-2*x*y+y^2/2";
+ *       niveauline = [-3,-2,-1,-0.5, 0, 1,2,3];
+ *       niveaunum = niveauline.length;
+ *       for (let i = 0; JXG.Math.lt(i, niveaunum); i++) {
+ *         let niveaui = niveauline[i];
+ *         niveauopac.push(((i + 1) / (niveaunum + 1)));
+ *         cf.push(board.create("implicitcurve", [
+ *           inputFun + "-(" + niveaui.toFixed(2) + ")", [-2, 2], [-2, 2]], {
+ *           strokeWidth: 2,
+ *           strokeColor: JXG.palette.red,
+ *           strokeOpacity: niveauopac[i],
+ *           needsRegularUpdate: false,
+ *           name: "niveau"+i,
+ *           visible: true
+ *         }));
+ *       }
+ *       legend = board.create('legend', [-1.75, 1.75], {
+ *         labels: niveauline,
+ *         colors: [cf[0].visProp.strokecolor],
+ *         strokeOpacity: niveauopac,
+ *         linelength: 0.2,
+ *         frozen:true
+ *       }
+ *       );
+ *
+ *
+ *     })();
+ *
+ * </script>
+ *
  *
  */
 JXG.createLegend = function (board, parents, attributes) {
