@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,7 +36,7 @@
 import JXG from "../jxg.js";
 
 var major = 1,
-    minor = 10,
+    minor = 11,
     patch = 1,
     add = '', // 'dev' 'beta'
     version = major + '.' + minor + '.' + patch + (add ? '-' + add : ''),
@@ -122,6 +122,9 @@ constants =
     OBJECT_TYPE_CIRCLE3D: 41,
     OBJECT_TYPE_INTERSECTION_CIRCLE3D: 42,
     OBJECT_TYPE_TEXT3D: 43,
+    OBJECT_TYPE_FACE3D: 44,
+    OBJECT_TYPE_POLYHEDRON3D: 45,
+    OBJECT_TYPE_POLYGON3D: 46,
 
     // IMPORTANT:
     // ----------
