@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -98,21 +98,21 @@ JXG.extend(
                 r,
                 prec,
                 type,
-                unit = Type.evaluate(this.visProp.sizeunit);
+                unit = this.evalVisProp('sizeunit');
 
-            if (Type.isObject(Type.evaluate(this.visProp.precision))) {
+            if (Type.isObject(this.evalVisProp('precision'))) {
                 type = this.board._inputDevice;
-                prec = Type.evaluate(this.visProp.precision[type]);
+                prec = this.evalVisProp('precision.' + type);
             } else {
                 // 'inherit'
                 prec = this.board.options.precision.hasPoint;
             }
-            r = parseFloat(Type.evaluate(this.visProp.size));
+            r = parseFloat(this.evalVisProp('size'));
             if (unit === "user") {
                 r *= Math.sqrt(Math.abs(this.board.unitX * this.board.unitY));
             }
 
-            r += parseFloat(Type.evaluate(this.visProp.strokewidth)) * 0.5;
+            r += parseFloat(this.evalVisProp('strokewidth')) * 0.5;
             if (r < prec) {
                 r = prec;
             }
@@ -130,7 +130,7 @@ JXG.extend(
 
             this.updateCoords(fromParent);
 
-            if (Type.evaluate(this.visProp.trace)) {
+            if (this.evalVisProp('trace')) {
                 this.cloneToBackground(true);
             }
 
@@ -152,21 +152,19 @@ JXG.extend(
                 return this;
             }
 
+            this.transformations[0].update();
             if (this === this.baseElement) {
                 // Case of bindTo
-                c = this.transformations[0].apply(this.baseElement, "self");
-                this.coords.setCoordinates(Const.COORDS_BY_USER, c);
+                c = this.transformations[0].apply(this, "self");
             } else {
                 c = this.transformations[0].apply(this.baseElement);
             }
+            for (i = 1; i < this.transformations.length; i++) {
+                this.transformations[i].update();
+                c = Mat.matVecMult(this.transformations[i].matrix, c);
+            }
             this.coords.setCoordinates(Const.COORDS_BY_USER, c);
 
-            for (i = 1; i < this.transformations.length; i++) {
-                this.coords.setCoordinates(
-                    Const.COORDS_BY_USER,
-                    this.transformations[i].apply(this)
-                );
-            }
             return this;
         },
 
@@ -381,7 +379,7 @@ JXG.extend(
             if (Type.isPoint(el)) {
                 return this.Dist(el) < tol;
             } else if (el.elementClass === Const.OBJECT_CLASS_LINE) {
-                if (el.elType === "segment" && !Type.evaluate(this.visProp.alwaysintersect)) {
+                if (el.elType === "segment" && !this.evalVisProp('alwaysintersect')) {
                     arr = JXG.Math.Geometry.projectCoordsToSegment(
                         this.coords.usrCoords,
                         el.point1.coords.usrCoords,
@@ -400,7 +398,7 @@ JXG.extend(
                     return Geometry.distPointLine(this.coords.usrCoords, el.stdform) < tol;
                 }
             } else if (el.elementClass === Const.OBJECT_CLASS_CIRCLE) {
-                if (Type.evaluate(el.visProp.hasinnerpoints)) {
+                if (el.evalVisProp('hasinnerpoints')) {
                     return this.Dist(el.center) < el.Radius() + tol;
                 }
                 return Math.abs(this.Dist(el.center) - el.Radius()) < tol;
@@ -408,7 +406,7 @@ JXG.extend(
                 crds = Geometry.projectPointToCurve(this, el, this.board)[0];
                 return Geometry.distance(this.coords.usrCoords, crds.usrCoords, 3) < tol;
             } else if (el.type === Const.OBJECT_TYPE_POLYGON) {
-                if (Type.evaluate(el.visProp.hasinnerpoints)) {
+                if (el.evalVisProp('hasinnerpoints')) {
                     if (
                         el.pnpoly(
                             this.coords.usrCoords[1],
@@ -432,21 +430,7 @@ JXG.extend(
 
         // Already documented in GeometryElement
         cloneToBackground: function () {
-            var copy = {};
-
-            copy.id = this.id + "T" + this.numTraces;
-            this.numTraces += 1;
-
-            copy.coords = this.coords;
-            copy.visProp = Type.deepCopy(this.visProp, this.visProp.traceattributes, true);
-            copy.visProp.layer = this.board.options.layer.trace;
-            copy.elementClass = Const.OBJECT_CLASS_POINT;
-            copy.board = this.board;
-            Type.clearVisPropOld(copy);
-
-            copy.visPropCalc = {
-                visible: Type.evaluate(copy.visProp.visible)
-            };
+            var copy = Type.getCloneObject(this);
 
             this.board.renderer.drawPoint(copy);
             this.traces[copy.id] = copy.rendNode;
@@ -457,7 +441,7 @@ JXG.extend(
 );
 
 /**
- * @class This element is used to provide a constructor for a general point. A free point is created if the given parent elements are all numbers
+ * @class Construct a free or a fixed point. A free point is created if the given parent elements are all numbers
  * and the property fixed is not set or set to false. If one or more parent elements is not a number but a string containing a GEONE<sub>x</sub>T
  * constraint or a function the point will be considered as constrained). That means that the user won't be able to change the point's
  * position directly.
@@ -526,7 +510,7 @@ JXG.createPoint = function (board, parents, attributes) {
 };
 
 /**
- * @class This element is used to provide a constructor for a glider point.
+ * @class A glider is a point bound to a line, circle or curve or even another point.
  * @pseudo
  * @description A glider is a point which lives on another geometric element like a line, circle, curve, turtle.
  * @name Glider
@@ -598,8 +582,9 @@ JXG.createGlider = function (board, parents, attributes) {
 };
 
 /**
- * @class An intersection point is a point which lives on two JSXGraph elements, i.e. it is one point of the set
- * consisting of the intersection points of the two elements. The following element types can be (mutually) intersected: line, circle,
+ * @class A point intersecting two 1-dimensional elements.
+ * It is one point of the set  * consisting of the intersection points of the two elements.
+ * The following element types can be (mutually) intersected: line, circle,
  * curve, polygon, polygonal chain.
  *
  * @pseudo
@@ -699,7 +684,7 @@ JXG.createIntersectionPoint = function (board, parents, attributes) {
 };
 
 /**
- * @class This element is used to provide a constructor for the "other" intersection point.
+ * @class Given a set of intersection points, this is another ("other") intersection point,
  * @pseudo
  * @description If two elements of type curve, circle or line intersect in more than one point, with this element it is possible
  * to construct the "other" intersection. This is a an intersection which is different from a supplied point or different from any
