@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -63,6 +63,9 @@ JXG.Polygon = function (board, vertices, attributes) {
 
     /**
      * References to the points defining the polygon. The last vertex is the same as the first vertex.
+     * Compared to the 3D {@link JXG.Polygon3D#vertices}, it contains one point more, i.e. for a quadrangle
+     * 'vertices' contains five points, the last one being
+     * a copy of the first one. In a 3D quadrangle, 'vertices' will contain four points.
      * @type Array
      */
     this.vertices = [];
@@ -87,7 +90,7 @@ JXG.Polygon = function (board, vertices, attributes) {
     }
 
     /**
-     * References to the border lines of the polygon.
+     * References to the border lines (edges) of the polygon.
      * @type Array
      */
     this.borders = [];
@@ -206,7 +209,7 @@ JXG.extend(
          *
          */
         pnpoly: function (x_in, y_in, coord_type) {
-            return Geometry.pnpoly(x_in, y_in, this.vertices, coord_type);
+            return Geometry.pnpoly(x_in, y_in, this.vertices, coord_type, this.board);
         },
 
         /**
@@ -218,7 +221,7 @@ JXG.extend(
         hasPoint: function (x, y) {
             var i, len;
 
-            if (Type.evaluate(this.visProp.hasinnerpoints)) {
+            if (this.evalVisProp('hasinnerpoints')) {
                 // All points of the polygon trigger hasPoint: inner and boundary points
                 if (this.pnpoly(x, y)) {
                     return true;
@@ -333,21 +336,10 @@ JXG.extend(
 
         // documented in geometry element
         cloneToBackground: function () {
-            var copy = {},
-                er;
+            var er,
+                copy = Type.getCloneObject(this);
 
-            copy.id = this.id + "T" + this.numTraces;
-            this.numTraces++;
             copy.vertices = this.vertices;
-            copy.visProp = Type.deepCopy(this.visProp, this.visProp.traceattributes, true);
-            copy.visProp.layer = this.board.options.layer.trace;
-            copy.board = this.board;
-            Type.clearVisPropOld(copy);
-
-            copy.visPropCalc = {
-                visible: Type.evaluate(copy.visProp.visible)
-            };
-
             er = this.board.renderer.enhancedRendering;
             this.board.renderer.enhancedRendering = true;
             this.board.renderer.drawPolygon(copy);
@@ -889,7 +881,7 @@ JXG.extend(
         snapToGrid: function () {
             var i, force;
 
-            if (Type.evaluate(this.visProp.snaptogrid)) {
+            if (this.evalVisProp('snaptogrid')) {
                 force = true;
             } else {
                 force = false;
@@ -1123,7 +1115,9 @@ JXG.extend(
 );
 
 /**
- * @class A polygon is an area enclosed by a set of border lines which are determined by
+ * @class A polygon is a plane figure made up of line segments (the borders) connected
+ * to form a closed polygonal chain.
+ * It is determined by
  * <ul>
  *    <li> a list of points or
  *    <li> a list of coordinate arrays or
@@ -1274,7 +1268,9 @@ JXG.createPolygon = function (board, parents, attributes) {
 };
 
 /**
- * @class Constructs a regular polygon. It needs two points which define the base line and the number of vertices.
+ * @class A regular polygon is a polygon that is
+ * direct equiangular (all angles are equal in measure) and equilateral (all sides have the same length).
+ * It needs two points which define the base line and the number of vertices.
  * @pseudo
  * @description Constructs a regular polygon. It needs two points which define the base line and the number of vertices, or a set of points.
  * @constructor
@@ -1401,7 +1397,8 @@ JXG.createRegularPolygon = function (board, parents, attributes) {
 };
 
 /**
- * @class  A polygonal chain is a connected series of line segments determined by
+ * @class  A polygonal chain is a connected series of line segments (borders).
+ * It is determined by
  * <ul>
  *    <li> a list of points or
  *    <li> a list of coordinate arrays or
@@ -1475,7 +1472,7 @@ JXG.createPolygonalChain = function (board, parents, attributes) {
 };
 
 /**
- * @class Parallelogram element. This is a quadrilateral with parallel opposite sides.
+ * @class A quadrilateral polygon with parallel opposite sides.
  * @pseudo
  * @description Constructs a parallelogram. As input, three points or coordinate arrays are expected.
  * @constructor
