@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -179,7 +179,7 @@ JXG.extend(
         //                     var delta, b, dist,
         //                     number_major_tick_intervals = 5;
 
-        //                 if (Type.evaluate(this.visProp.insertticks)) {
+        //                 if (this.evalVisProp('insertticks')) {
         //                     b = this.getLowerAndUpperBounds(this.getZeroCoordinates(), 'ticksdistance');
         //                     dist = b.upper - b.lower;
 
@@ -202,7 +202,7 @@ JXG.extend(
         //                 }
 
         //                 // In case of insertTicks==false
-        //                 return Type.evaluate(this.visProp.ticksdistance);
+        //                 return this.evalVisProp('ticksdistance');
         //                 // return ticks;
         //             // };
         //         },
@@ -218,21 +218,22 @@ JXG.extend(
             var i, t, r, type,
                 len = (this.ticks && this.ticks.length) || 0;
 
-            if (Type.isObject(Type.evaluate(this.visProp.precision))) {
-                type = this.board._inputDevice;
-                r = Type.evaluate(this.visProp.precision[type]);
-            } else {
-                // 'inherit'
-                r = this.board.options.precision.hasPoint;
-            }
-            r += Type.evaluate(this.visProp.strokewidth) * 0.5;
             if (
-                !Type.evaluate(this.line.visProp.scalable) ||
+                !this.line.evalVisProp('scalable') ||
                 this.line.elementClass === Const.OBJECT_CLASS_CURVE
             ) {
                 return false;
             }
 
+            if (Type.isObject(this.evalVisProp('precision'))) {
+                type = this.board._inputDevice;
+                r = this.evalVisProp('precision.' + type);
+            } else {
+                // 'inherit'
+                r = this.board.options.precision.hasPoint;
+            }
+            r += this.evalVisProp('strokewidth') * 0.5;
+
             // Ignore non-axes and axes that are not horizontal or vertical
             if (
                 this.line.stdform[1] !== 0 &&
@@ -263,8 +264,8 @@ JXG.extend(
                             Math.abs(t[0][0] - t[0][1]) >= 1 ||
                             Math.abs(t[1][0] - t[1][1]) >= 1
                         ) {
+                            // Allow dragging near axes only.
                             if (this.line.stdform[1] === 0) {
-                                // Allow dragging near axes only.
                                 if (
                                     Math.abs(y - this.line.point1.coords.scrCoords[2]) < 2 * r &&
                                     t[0][0] - r < x && x < t[0][1] + r
@@ -302,7 +303,7 @@ JXG.extend(
 
             if (
                 this.line.type !== Const.OBJECT_TYPE_AXIS ||
-                !Type.evaluate(this.line.visProp.scalable)
+                !this.line.evalVisProp('scalable')
             ) {
                 return this;
             }
@@ -365,7 +366,7 @@ JXG.extend(
                 };
             }
 
-            if (Type.evaluate(this.visProp.type) === "polar") {
+            if (this.evalVisProp('type') === "polar") {
                 bb = this.board.getBoundingBox();
                 r_max = Math.max(
                     Mat.hypot(bb[0], bb[1]),
@@ -397,8 +398,8 @@ JXG.extend(
                 mi,
                 ma,
                 len,
-                distMaj = Type.evaluate(this.visProp.majorheight) * 0.5,
-                distMin = Type.evaluate(this.visProp.minorheight) * 0.5;
+                distMaj = this.evalVisProp('majorheight') * 0.5,
+                distMin = this.evalVisProp('minorheight') * 0.5;
 
             // For curves:
             if (Type.exists(pos)) {
@@ -444,8 +445,8 @@ JXG.extend(
             this.dyMin *= (distMin / d) * this.board.unitY;
 
             // Grid-like ticks?
-            this.minStyle = Type.evaluate(this.visProp.minorheight) < 0 ? "infinite" : "finite";
-            this.majStyle = Type.evaluate(this.visProp.majorheight) < 0 ? "infinite" : "finite";
+            this.minStyle = this.evalVisProp('minorheight') < 0 ? "infinite" : "finite";
+            this.majStyle = this.evalVisProp('majorheight') < 0 ? "infinite" : "finite";
         },
 
         /**
@@ -462,7 +463,7 @@ JXG.extend(
         getZeroCoordinates: function () {
             var c1x, c1y, c1z, c2x, c2y, c2z,
                 t, mi, ma,
-                ev_a = Type.evaluate(this.visProp.anchor);
+                ev_a = this.evalVisProp('anchor');
 
             if (this.line.elementClass === Const.OBJECT_CLASS_LINE) {
                 if (this.line.type === Const.OBJECT_TYPE_AXIS) {
@@ -549,9 +550,9 @@ JXG.extend(
                 // angle,
                 a1, a2, m1, m2,
                 eps = Mat.eps * 10,
-                ev_sf = Type.evaluate(this.line.visProp.straightfirst),
-                ev_sl = Type.evaluate(this.line.visProp.straightlast),
-                ev_i = Type.evaluate(this.visProp.includeboundaries);
+                ev_sf = this.line.evalVisProp('straightfirst'),
+                ev_sl = this.line.evalVisProp('straightlast'),
+                ev_i = this.evalVisProp('includeboundaries');
 
             // The line's defining points that will be adjusted to be within the board limits
             if (this.line.elementClass === Const.OBJECT_CLASS_CURVE) {
@@ -585,7 +586,7 @@ JXG.extend(
                 Geometry.calcStraight(this.line, point1, point2, 0);
                 m1 = this.getDistanceFromZero(coordsZero, point1);
                 m2 = this.getDistanceFromZero(coordsZero, point2);
-                Geometry.calcStraight(this.line, point1, point2, Type.evaluate(this.line.visProp.margin));
+                Geometry.calcStraight(this.line, point1, point2, this.line.evalVisProp('margin'));
                 m1 = this.getDistanceFromZero(coordsZero, point1) - m1;
                 m2 = this.getDistanceFromZero(coordsZero, point2).m2;
             } else {
@@ -595,8 +596,8 @@ JXG.extend(
             }
 
             // Shorten ticks bounds such that ticks are not through arrow heads
-            fA = Type.evaluate(this.line.visProp.firstarrow);
-            lA = Type.evaluate(this.line.visProp.lastarrow);
+            fA = this.line.evalVisProp('firstarrow');
+            lA = this.line.evalVisProp('lastarrow');
 
             a1 = this.getDistanceFromZero(coordsZero, point1);
             a2 = this.getDistanceFromZero(coordsZero, point2);
@@ -606,7 +607,7 @@ JXG.extend(
                 // Ticks would appear to be too nervous.
                 arrowData = this.board.renderer.getArrowHeadData(
                     this.line,
-                    Type.evaluate(this.line.visProp.strokewidth),
+                    this.line.evalVisProp('strokewidth'),
                     ''
                 );
 
@@ -715,10 +716,10 @@ JXG.extend(
             var tickPosition,
                 eps = Mat.eps,
                 deltas, ticksDelta,
-                // ev_mia = Type.evaluate(this.visProp.minorticksinarrow),
-                // ev_maa = Type.evaluate(this.visProp.minorticksinarrow),
-                // ev_mla = Type.evaluate(this.visProp.minorticksinarrow),
-                ev_mt = Type.evaluate(this.visProp.minorticks);
+                // ev_mia = this.evalVisProp('minorticksinarrow'),
+                // ev_maa = this.evalVisProp('minorticksinarrow'),
+                // ev_mla = this.evalVisProp('minorticksinarrow'),
+                ev_mt = this.evalVisProp('minorticks');
 
             // Determine a proposed distance between major ticks in user units
             ticksDelta = this.getDistanceMajorTicks();
@@ -732,7 +733,7 @@ JXG.extend(
                 deltas = this.getXandYdeltas();
             }
 
-            ticksDelta *= Type.evaluate(this.visProp.scale);
+            ticksDelta *= this.evalVisProp('scale');
 
             // In case of insertTicks, adjust ticks distance to satisfy the minTicksDistance restriction.
             // if (ev_it) { // } && this.minTicksDistance > Mat.eps) {
@@ -746,12 +747,20 @@ JXG.extend(
             if (ticksDelta < Mat.eps) {
                 return;
             }
+            if (Math.abs(bounds.upper - bounds.lower) > ticksDelta * 2048) {
+                JXG.warn("JSXGraph ticks: too many ticks (>2048). Please increase ticksDistance.");
+                return;
+            }
 
             // Position ticks from zero to the positive side while not reaching the upper boundary
             tickPosition = 0;
-            if (!Type.evaluate(this.visProp.drawzero)) {
+            if (!this.evalVisProp('drawzero')) {
                 tickPosition = ticksDelta;
             }
+            if (tickPosition < bounds.lower) {
+                // Jump from 0 to bounds.lower
+                tickPosition = Math.floor((bounds.lower - eps) / ticksDelta) * ticksDelta;
+            }
             while (tickPosition <= bounds.upper + eps) {
                 // Only draw ticks when we are within bounds, ignore case where tickPosition < lower < upper
                 if (tickPosition >= bounds.lower - eps) {
@@ -759,7 +768,7 @@ JXG.extend(
                 }
                 tickPosition += ticksDelta;
 
-                // Emergency out
+                // Emergency out (probably obsolete)
                 if (bounds.upper - tickPosition > ticksDelta * 10000) {
                     break;
                 }
@@ -767,6 +776,10 @@ JXG.extend(
 
             // Position ticks from zero (not inclusive) to the negative side while not reaching the lower boundary
             tickPosition = -ticksDelta;
+            if (tickPosition > bounds.upper) {
+                // Jump from -ticksDelta to bounds.upper
+                tickPosition = Math.ceil((bounds.upper + eps) / (-ticksDelta)) * (-ticksDelta);
+            }
             while (tickPosition >= bounds.lower - eps) {
                 // Only draw ticks when we are within bounds, ignore case where lower < upper < tickPosition
                 if (tickPosition <= bounds.upper + eps) {
@@ -774,7 +787,7 @@ JXG.extend(
                 }
                 tickPosition -= ticksDelta;
 
-                // Emergency out
+                // Emergency out (probably obsolete)
                 if (tickPosition - bounds.lower > ticksDelta * 10000) {
                     break;
                 }
@@ -803,17 +816,17 @@ JXG.extend(
                 numberMajorTicks = 5,
                 maxDist, minDist, ev_minti;
 
-            if (Type.evaluate(this.visProp.insertticks)) {
+            if (this.evalVisProp('insertticks')) {
                 // Case of insertTicks==true:
                 // Here, we ignore the attribute 'margin'
                 b = this.getLowerAndUpperBounds(this.getZeroCoordinates(), '');
 
                 dist = (b.upper - b.lower);
-                scale = Type.evaluate(this.visProp.scale);
+                scale = this.evalVisProp('scale');
 
                 maxDist = dist / (numberMajorTicks + 1) / scale;
-                minDist = Type.evaluate(this.visProp.minticksdistance) / scale;
-                ev_minti = Type.evaluate(this.visProp.minorticks);
+                minDist = this.evalVisProp('minticksdistance') / scale;
+                ev_minti = this.evalVisProp('minorticks');
 
                 d = this.getXandYdeltas();
                 d.x *= this.board.unitX;
@@ -849,7 +862,7 @@ JXG.extend(
             }
 
             // Case of insertTicks==false
-            return Type.evaluate(this.visProp.ticksdistance);
+            return this.evalVisProp('ticksdistance');
         },
 
         //         /**
@@ -868,8 +881,8 @@ JXG.extend(
         //                 // bounds,
         //                 distScr,
         //                 sgn = 1,
-        //                 ev_mintd = Type.evaluate(this.visProp.minticksdistance),
-        //                 ev_minti = Type.evaluate(this.visProp.minorticks);
+        //                 ev_mintd = this.evalVisProp('minticksdistance'),
+        //                 ev_minti = this.evalVisProp('minorticks');
 
         //             if (this.line.elementClass === Const.OBJECT_CLASS_CURVE) {
         //                 return ticksDelta;
@@ -926,7 +939,7 @@ JXG.extend(
                 tickCoords,
                 ti,
                 isLabelPosition,
-                ticksPerLabel = Type.evaluate(this.visProp.ticksperlabel),
+                ticksPerLabel = this.evalVisProp('ticksperlabel'),
                 labelVal = null;
 
             // Calculates tick coordinates
@@ -948,12 +961,12 @@ JXG.extend(
             // a multiple of the number of minorticks+1
             tickCoords.major =
                 Math.round(tickPosition / ticksDelta) %
-                (Type.evaluate(this.visProp.minorticks) + 1) ===
+                (this.evalVisProp('minorticks') + 1) ===
                 0;
 
             if (!ticksPerLabel) {
                 // In case of null, 0 or false, majorTicks are labelled
-                ticksPerLabel = Type.evaluate(this.visProp.minorticks) + 1;
+                ticksPerLabel = this.evalVisProp('minorticks') + 1;
             }
             isLabelPosition = Math.round(tickPosition / ticksDelta) % ticksPerLabel === 0;
 
@@ -962,7 +975,7 @@ JXG.extend(
             ti = this.createTickPath(tickCoords, tickCoords.major);
             if (ti.length === 3) {
                 this.ticks.push(ti);
-                if (isLabelPosition && Type.evaluate(this.visProp.drawlabels)) {
+                if (isLabelPosition && this.evalVisProp('drawlabels')) {
                     // Create a label at this position
                     this.labelsData.push(
                         this.generateLabelData(
@@ -996,7 +1009,7 @@ JXG.extend(
                 fixedTick,
                 hasLabelOverrides = Type.isArray(this.visProp.labels),
                 deltas,
-                ev_dl = Type.evaluate(this.visProp.drawlabels);
+                ev_dl = this.evalVisProp('drawlabels');
 
             if (this.line.elementClass === Const.OBJECT_CLASS_LINE) {
                 // Calculate x and y distances between two points on the line which are 1 unit apart
@@ -1031,7 +1044,7 @@ JXG.extend(
 
                     if (ev_dl && (hasLabelOverrides || Type.exists(this.visProp.labels[i]))) {
                         labelText = hasLabelOverrides
-                            ? Type.evaluate(this.visProp.labels[i])
+                            ? this.evalVisProp('labels.' + i)
                             : fixedTick;
                         this.labelsData.push(
                             this.generateLabelData(
@@ -1136,21 +1149,21 @@ JXG.extend(
                 dxs = this.dxMaj;
                 dys = this.dyMaj;
                 style = this.majStyle;
-                te0 = Type.evaluate(this.visProp.majortickendings[0]) > 0;
-                te1 = Type.evaluate(this.visProp.majortickendings[1]) > 0;
+                te0 = this.evalVisProp('majortickendings.0') > 0;
+                te1 = this.evalVisProp('majortickendings.1') > 0;
             } else {
                 dxs = this.dxMin;
                 dys = this.dyMin;
                 style = this.minStyle;
-                te0 = Type.evaluate(this.visProp.tickendings[0]) > 0;
-                te1 = Type.evaluate(this.visProp.tickendings[1]) > 0;
+                te0 = this.evalVisProp('tickendings.0') > 0;
+                te1 = this.evalVisProp('tickendings.1') > 0;
             }
             lineStdForm = [-dys * c[1] - dxs * c[2], dys, dxs];
 
             // For all ticks regardless if of finite or infinite
             // tick length the intersection with the canvas border is
             // computed.
-            if (major && Type.evaluate(this.visProp.type) === "polar") {
+            if (major && this.evalVisProp('type') === "polar") {
                 // polar style
                 bb = this.board.getBoundingBox();
                 full = 2.0 * Math.PI;
@@ -1184,7 +1197,7 @@ JXG.extend(
                 if (style === 'infinite') {
                     // Problematic are infinite ticks which have set tickendings:[0,1].
                     // For example, this is the default setting for minor ticks
-                    if (Type.evaluate(this.visProp.ignoreinfinitetickendings)) {
+                    if (this.evalVisProp('ignoreinfinitetickendings')) {
                         te0 = te1 = true;
                     }
                     intersection = Geometry.meetLineBoard(lineStdForm, this.board);
@@ -1248,9 +1261,9 @@ JXG.extend(
                         }
                     }
                 } else {
-                    if (Type.evaluate(this.visProp.face) === ">") {
+                    if (this.evalVisProp('face') === ">") {
                         alpha = Math.PI / 4;
-                    } else if (Type.evaluate(this.visProp.face) === "<") {
+                    } else if (this.evalVisProp('face') === "<") {
                         alpha = -Math.PI / 4;
                     } else {
                         alpha = 0;
@@ -1258,8 +1271,8 @@ JXG.extend(
                     dxr = Math.cos(alpha) * dxs - Math.sin(alpha) * dys;
                     dyr = Math.sin(alpha) * dxs + Math.cos(alpha) * dys;
 
-                    x[0] = c[1] + dxr * te0; // Type.evaluate(this.visProp.tickendings[0]);
-                    y[0] = c[2] - dyr * te0; // Type.evaluate(this.visProp.tickendings[0]);
+                    x[0] = c[1] + dxr * te0;
+                    y[0] = c[2] - dyr * te0;
                     x[1] = c[1];
                     y[1] = c[2];
 
@@ -1267,8 +1280,8 @@ JXG.extend(
                     dxr = Math.cos(alpha) * dxs - Math.sin(alpha) * dys;
                     dyr = Math.sin(alpha) * dxs + Math.cos(alpha) * dys;
 
-                    x[2] = c[1] - dxr * te1; // Type.evaluate(this.visProp.tickendings[1]);
-                    y[2] = c[2] + dyr * te1; // Type.evaluate(this.visProp.tickendings[1]);
+                    x[2] = c[1] - dxr * te1;
+                    y[2] = c[2] + dyr * te1;
                 }
 
                 // Check if (parts of) the tick is inside the canvas.
@@ -1290,31 +1303,31 @@ JXG.extend(
         formatLabelText: function (value) {
             var labelText,
                 digits,
-                ev_um = Type.evaluate(this.visProp.label.usemathjax),
-                ev_uk = Type.evaluate(this.visProp.label.usekatex),
-                ev_s = Type.evaluate(this.visProp.scalesymbol);
+                ev_um = this.evalVisProp('label.usemathjax'),
+                ev_uk = this.evalVisProp('label.usekatex'),
+                ev_s = this.evalVisProp('scalesymbol');
 
             if (Type.isNumber(value)) {
-                if (Type.evaluate(this.visProp.label.tofraction)) {
+                if (this.evalVisProp('label.tofraction')) {
                     if (ev_um) {
                         labelText = '\\(' + Type.toFraction(value, true) + '\\)';
                     } else {
                         labelText = Type.toFraction(value, ev_uk);
                     }
                 } else {
-                    digits = Type.evaluate(this.visProp.digits);
+                    digits = this.evalVisProp('digits');
                     if (this.useLocale()) {
                         labelText = this.formatNumberLocale(value, digits);
                     } else {
                         labelText = (Math.round(value * 1e11) / 1e11).toString();
 
                         if (
-                            labelText.length > Type.evaluate(this.visProp.maxlabellength) ||
+                            labelText.length > this.evalVisProp('maxlabellength') ||
                             labelText.indexOf("e") !== -1
                         ) {
-                            if (Type.evaluate(this.visProp.precision) !== 3 && digits === 3) {
+                            if (this.evalVisProp('precision') !== 3 && digits === 3) {
                                 // Use the deprecated attribute "precision"
-                                digits = Type.evaluate(this.visProp.precision);
+                                digits = this.evalVisProp('precision');
                             }
 
                             //labelText = value.toPrecision(digits).toString();
@@ -1323,7 +1336,7 @@ JXG.extend(
                     }
                 }
 
-                if (Type.evaluate(this.visProp.beautifulscientificticklabels)) {
+                if (this.evalVisProp('beautifulscientificticklabels')) {
                     labelText = this.beautifyScientificNotationLabel(labelText);
                 }
 
@@ -1347,7 +1360,7 @@ JXG.extend(
                 }
             }
 
-            if (Type.evaluate(this.visProp.useunicodeminus)) {
+            if (this.evalVisProp('useunicodeminus')) {
                 labelText = labelText.replace(/-/g, "\u2212");
             }
             return labelText;
@@ -1418,7 +1431,7 @@ JXG.extend(
                     // Point is zero
                     return "0";
                 }
-                value = distance / Type.evaluate(this.visProp.scale);
+                value = distance / this.evalVisProp('scale');
             }
             labelText = this.formatLabelText(value);
 
@@ -1439,7 +1452,7 @@ JXG.extend(
             // Test if large portions of the label are inside of the canvas
             // This is the last chance to abandon the creation of the label if it is mostly
             // outside of the canvas.
-            fs = Type.evaluate(this.visProp.label.fontsize);
+            fs = this.evalVisProp('label.fontsize');
             xa = [tick.scrCoords[1], tick.scrCoords[1]];
             ya = [tick.scrCoords[2], tick.scrCoords[2]];
             m = fs === undefined ? 12 : fs;
@@ -1448,8 +1461,8 @@ JXG.extend(
                 return null;
             }
 
-            xa = Type.evaluate(this.visProp.label.offset[0]);
-            ya = Type.evaluate(this.visProp.label.offset[1]);
+            xa = this.evalVisProp('label.offset')[0];
+            ya = this.evalVisProp('label.offset')[1];
 
             return {
                 x: tick.usrCoords[1] + xa / this.board.unitX,
@@ -1465,7 +1478,7 @@ JXG.extend(
          */
         update: function () {
             if (this.needsUpdate) {
-                //this.visPropCalc.visible = Type.evaluate(this.visProp.visible);
+                //this.visPropCalc.visible = this.evalVisProp('visible');
                 // A canvas with no width or height will create an endless loop, so ignore it
                 if (this.board.canvasWidth !== 0 && this.board.canvasHeight !== 0) {
                     this.calculateTicksCoordinates();
@@ -1541,15 +1554,9 @@ JXG.extend(
                     // A new text element is needed
                     this.labelCounter += 1;
 
-                    attr = {
-                        isLabel: true,
-                        layer: this.board.options.layer.line,
-                        highlightStrokeColor: this.board.options.text.strokeColor,
-                        highlightStrokeWidth: this.board.options.text.strokeWidth,
-                        highlightStrokeOpacity: this.board.options.text.strokeOpacity,
-                        priv: this.visProp.priv
-                    };
-                    attr = Type.deepCopy(attr, this.visProp.label);
+                    attr = Type.deepCopy(this.visProp.label);
+                    attr.isLabel = true;
+                    attr.priv = this.visProp.priv;
                     attr.id = this.id + ld.i + "Label" + this.labelCounter;
 
                     label = JXG.createText(this.board, [ld.x, ld.y, ld.t], attr);
@@ -1562,15 +1569,15 @@ JXG.extend(
 
                 // Look-ahead if the label inherits visibility.
                 // If yes, update label.
-                visible = Type.evaluate(this.visProp.label.visible);
+                visible = this.evalVisProp('label.visible');
                 if (visible === 'inherit') {
                     visible = this.visPropCalc.visible;
                 }
 
                 label.prepareUpdate().updateVisibility(visible).updateRenderer();
 
-                label.distanceX = Type.evaluate(this.visProp.label.offset[0]);
-                label.distanceY = Type.evaluate(this.visProp.label.offset[1]);
+                label.distanceX = this.evalVisProp('label.offset')[0];
+                label.distanceY = this.evalVisProp('label.offset')[1];
             }
 
             // Hide unused labels
@@ -1764,7 +1771,7 @@ JXG.createTicks = function (board, parents, attributes) {
 };
 
 /**
- * @class Hatches can be used to mark congruent lines or curves.
+ * @class Hatches are collections of short line segments used to mark congruent lines or curves.
  * @pseudo
  * @name Hatch
  * @augments JXG.Ticks
