@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -517,7 +517,7 @@ JXG.extend(
             } else {
                 pos = le - 1;
             }
-            return Type.evaluate(this.objects[pos].visProp[key]);
+            return this.objects[pos].evalVisProp(key);
         },
 
         /**
@@ -917,7 +917,7 @@ JXG.extend(
 );
 
 /**
- * @class This element is used to provide a constructor for a turtle.
+ * @class A turtle is a graphic paradigm similar to the programming languages Logo or PostScript.
  * @pseudo
  * @description  Creates a new turtle
  * @name Turtle
