@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -46,9 +46,11 @@ import Type from "../utils/type.js";
 import Const from "../base/constants.js";
 
 /**
- * @class An arc is a segment of the circumference of a circle. It is defined by a center, one point that
+ * @class An arc is a partial circumference line of a circle.
+ * It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the arc.
- *
+ * <p>
+ * As a curve the arc has curve length 6.
  * @pseudo
  * @name Arc
  * @augments Curve
@@ -120,7 +122,7 @@ JXG.createArc = function (board, parents, attributes) {
     }
 
     attr = Type.copyAttributes(attributes, board.options, "arc");
-    el = board.create("curve", [[0], [0]], attr);
+    el = board.create("curve", [[0], [0], 0, 4], attr);
 
     el.elType = "arc";
     el.setParents(points);
@@ -178,8 +180,8 @@ JXG.createArc = function (board, parents, attributes) {
         el.anglepoint.addChild(el);
     }
 
-    // should be documented in options
-    el.useDirection = attr.usedirection;
+    // This attribute is necessary for circumCircleArcs
+    el.useDirection = attr.usedirection; // This makes the attribute immutable
 
     // documented in JXG.Curve
     /**
@@ -187,17 +189,13 @@ JXG.createArc = function (board, parents, attributes) {
      * @ignore
      */
     el.updateDataArray = function () {
-        var ar,
-            phi,
-            det,
-            p0c,
-            p1c,
-            p2c,
+        var ar, phi, det,
+            p0c, p1c, p2c,
             sgn = 1,
             A = this.radiuspoint,
             B = this.center,
             C = this.anglepoint,
-            ev_s = Type.evaluate(this.visProp.selection);
+            ev_s = this.evalVisProp('selection');
 
         phi = Geometry.rad(A, B, C);
         if ((ev_s === "minor" && phi > Math.PI) || (ev_s === "major" && phi < Math.PI)) {
@@ -320,13 +318,13 @@ JXG.createArc = function (board, parents, attributes) {
             type,
             r = this.Radius();
 
-        if (Type.evaluate(this.visProp.hasinnerpoints)) {
+        if (this.evalVisProp('hasinnerpoints')) {
             return this.hasPointSector(x, y);
         }
 
-        if (Type.isObject(Type.evaluate(this.visProp.precision))) {
+        if (Type.isObject(this.evalVisProp('precision'))) {
             type = this.board._inputDevice;
-            prec = Type.evaluate(this.visProp.precision[type]);
+            prec = this.evalVisProp('precision.' + type);
         } else {
             // 'inherit'
             prec = this.board.options.precision.hasPoint;
@@ -389,10 +387,9 @@ JXG.createArc = function (board, parents, attributes) {
      */
     el.getLabelAnchor = function () {
         var coords,
-            vec,
-            vecx,
-            vecy,
+            vec, vecx, vecy,
             len,
+            pos = this.label.evalVisProp('position'),
             angle = Geometry.rad(this.radiuspoint, this.center, this.anglepoint),
             dx = 10 / this.board.unitX,
             dy = 10 / this.board.unitY,
@@ -400,7 +397,7 @@ JXG.createArc = function (board, parents, attributes) {
             pmc = this.center.coords.usrCoords,
             bxminusax = p2c[1] - pmc[1],
             byminusay = p2c[2] - pmc[2],
-            ev_s = Type.evaluate(this.visProp.selection),
+            ev_s = this.evalVisProp('selection'),
             l_vp = this.label ? this.label.visProp : this.visProp.label;
 
         // If this is uncommented, the angle label can not be dragged
@@ -408,30 +405,39 @@ JXG.createArc = function (board, parents, attributes) {
         //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
         //}
 
-        if ((ev_s === "minor" && angle > Math.PI) || (ev_s === "major" && angle < Math.PI)) {
-            angle = -(2 * Math.PI - angle);
+        if (
+            !Type.isString(pos) ||
+            (pos.indexOf('right') < 0 && pos.indexOf('left') < 0)
+        ) {
+
+            if ((ev_s === "minor" && angle > Math.PI) || (ev_s === "major" && angle < Math.PI)) {
+                angle = -(2 * Math.PI - angle);
+            }
+
+            coords = new Coords(
+                Const.COORDS_BY_USER,
+                [
+                    pmc[1] + Math.cos(angle * 0.5) * bxminusax - Math.sin(angle * 0.5) * byminusay,
+                    pmc[2] + Math.sin(angle * 0.5) * bxminusax + Math.cos(angle * 0.5) * byminusay
+                ],
+                this.board
+            );
+
+            vecx = coords.usrCoords[1] - pmc[1];
+            vecy = coords.usrCoords[2] - pmc[2];
+
+            len = Mat.hypot(vecx, vecy);
+            vecx = (vecx * (len + dx)) / len;
+            vecy = (vecy * (len + dy)) / len;
+            vec = [pmc[1] + vecx, pmc[2] + vecy];
+
+            l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
+
+            return new Coords(Const.COORDS_BY_USER, vec, this.board);
+        } else {
+            return this.getLabelPosition(pos, this.label.evalVisProp('distance'));
         }
 
-        coords = new Coords(
-            Const.COORDS_BY_USER,
-            [
-                pmc[1] + Math.cos(angle * 0.5) * bxminusax - Math.sin(angle * 0.5) * byminusay,
-                pmc[2] + Math.sin(angle * 0.5) * bxminusax + Math.cos(angle * 0.5) * byminusay
-            ],
-            this.board
-        );
-
-        vecx = coords.usrCoords[1] - pmc[1];
-        vecy = coords.usrCoords[2] - pmc[2];
-
-        len = Mat.hypot(vecx, vecy);
-        vecx = (vecx * (len + dx)) / len;
-        vecy = (vecy * (len + dy)) / len;
-        vec = [pmc[1] + vecx, pmc[2] + vecy];
-
-        l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
-
-        return new Coords(Const.COORDS_BY_USER, vec, this.board);
     };
 
     // documentation in jxg.circle
@@ -527,7 +533,7 @@ JXG.createSemicircle = function (board, parents, attributes) {
 JXG.registerElement("semicircle", JXG.createSemicircle);
 
 /**
- * @class A circumcircle arc is an {@link Arc} defined by three points. All three points lie on the arc.
+ * @class A partial circum circle through three points.
  * @pseudo
  * @name CircumcircleArc
  * @augments Arc
@@ -603,8 +609,8 @@ JXG.createCircumcircleArc = function (board, parents, attributes) {
 JXG.registerElement("circumcirclearc", JXG.createCircumcircleArc);
 
 /**
- * @class A minor arc is a segment of the circumference of a circle having measure less than or equal to
- * 180 degrees (pi radians). It is defined by a center, one point that
+ * @class A minor arc given by three points is that part of the circumference of a circle having
+ * measure at most 180 degrees (pi radians). It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the arc.
  * @pseudo
  * @name MinorArc
@@ -642,8 +648,8 @@ JXG.createMinorArc = function (board, parents, attributes) {
 JXG.registerElement("minorarc", JXG.createMinorArc);
 
 /**
- * @class A major arc is a segment of the circumference of a circle having measure greater than or equal to
- * 180 degrees (pi radians). It is defined by a center, one point that
+ * @class A major arc given by three points is that part of the circumference of a circle having
+ * measure at least 180 degrees (pi radians). It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the arc.
  * @pseudo
  * @name MajorArc
