@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -50,8 +50,7 @@ var priv = {
 };
 
 /**
- * @class This element is used to provide a constructor for special texts containing a
- * form button element.
+ * @class A text element that contains an HTML button tag.
  * For this element, the attribute "display" has to have the value 'html' (which is the default).
  *
  * <p><b>Setting a CSS class:</b> The attribute <tt>cssClass</tt> affects the HTML div element that contains the button element. To change the CSS properties of the HTML button element a selector of the form
@@ -250,7 +249,7 @@ JXG.createButton = function (board, parents, attributes) {
     //}
 
     // 1. Create empty button
-    par = [parents[0], parents[1], '<button type="button" style="width:100%;"></button>'];
+    par = [parents[0], parents[1], '<button type="button" style="width:100%;" tabindex="0"></button>'];
     t = board.create("text", par, attr);
     t.type = Type.OBJECT_TYPE_BUTTON;
 
