@@ -1,5 +1,5 @@
 /*
-    Copyright 2018-2024
+    Copyright 2018-2025
         Alfred Wassermann,
         Tigran Saluev
 
@@ -36,7 +36,8 @@ import JXG from "../jxg.js";
 import Type from "../utils/type.js";
 
 /**
- * @class A comb to display domains of inequalities.
+ * @class A marker to display domains of inequalities.
+ * The comb element is defined by two points.
  * @pseudo
  * @name Comb
  * @augments JXG.Curve
@@ -202,10 +203,10 @@ JXG.createComb = function (board, parents, attributes) {
             p2_inner = p2,
             ds, angle, width;
 
-        ds = Type.evaluate(c.visProp.frequency);
-        angle = -Type.evaluate(c.visProp.angle);
-        width = Type.evaluate(c.visProp.width);
-        if (Type.evaluate(c.visProp.reverse)) {
+        ds = c.evalVisProp('frequency');
+        angle = -c.evalVisProp('angle');
+        width = c.evalVisProp('width');
+        if (c.evalVisProp('reverse')) {
             p1_inner = p2;
             p2_inner = p1;
             angle = -angle;
