@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -88,8 +88,8 @@ JXG.createTapemeasure = function (board, parents, attributes) {
     attr = Type.copyAttributes(attributes, board.options, "tapemeasure", "point2");
     p2 = board.create("point", pos1, attr);
 
-    p1.setAttribute({ ignoredSnapToPoints: [p2.id] });
-    p2.setAttribute({ ignoredSnapToPoints: [p1.id] });
+    p1.setAttribute({ignoredSnapToPoints: [p2.id]});
+    p2.setAttribute({ignoredSnapToPoints: [p1.id]});
 
     // tape measure line
     attr = Type.copyAttributes(attributes, board.options, "tapemeasure");
@@ -116,7 +116,7 @@ JXG.createTapemeasure = function (board, parents, attributes) {
             n = "";
         }
         li.label.setText(function () {
-            var digits = Type.evaluate(li.label.visProp.digits);
+            var digits = li.label.evalVisProp('digits');
 
             if (li.label.useLocale()) {
                 return n + li.label.formatNumberLocale(p1.Dist(p2), digits);
@@ -194,7 +194,8 @@ JXG.createTapemeasure = function (board, parents, attributes) {
 JXG.registerElement("tapemeasure", JXG.createTapemeasure);
 
 /**
- * @class Measurement element. Under the hood this is a text element which has a method Value. The text to be displayed
+ * @class Display measurements of geometric elements and the arithmetic operations of measurements.
+ * Under the hood this is a text element which has a method Value. The text to be displayed
  * is the result of the evaluation of a prefix expression, see {@link JXG.PrefixParser}.
  * <p>
  * The purpose of this element is to display values of measurements of geometric objects, like the radius of a circle,
@@ -337,7 +338,7 @@ JXG.createMeasurement = function (board, parents, attributes) {
     };
 
     el.Dimension = function () {
-        var d = Type.evaluate(el.visProp.dim);
+        var d = el.evalVisProp('dim');
 
         if (d !== null) {
             return d;
@@ -345,18 +346,30 @@ JXG.createMeasurement = function (board, parents, attributes) {
         return Prefix.dimension(term);
     };
 
-    el.Unit = function () {
+    el.Unit = function (dimension) {
         var unit = '',
-            units = Type.evaluate(el.visProp.units),
+            units = el.evalVisProp('units'),
+            dim = dimension,
+            dims = {}, i;
+
+        if (!Type.exists(dim)) {
             dim = el.Dimension();
+        }
+
+        if (Type.isArray(dimension)) {
+            for (i = 0; i < dimension.length; i++) {
+                dims['dim' + dimension[i]] = el.Unit(dimension[i]);
+            }
+            return dims;
+        }
 
         if (Type.isObject(units) && Type.exists(units[dim]) && units[dim] !== false) {
-            unit = Type.evaluate(units[dim]);
+            unit = el.eval(units[dim]);
         } else if (Type.isObject(units) && Type.exists(units['dim' + dim]) && units['dim' + dim] !== false) {
             // In some cases, object keys must not be numbers. This allows key 'dim1' instead of '1'.
-            unit = Type.evaluate(units['dim' + dim]);
+            unit = el.eval(units['dim' + dim]);
         } else {
-            unit = Type.evaluate(el.visProp.baseunit);
+            unit = el.evalVisProp('baseunit');
 
             if (dim === 0) {
                 unit = '';
@@ -400,16 +413,16 @@ JXG.createMeasurement = function (board, parents, attributes) {
         var prefix = '',
             suffix = '',
             dim = el.Dimension(),
-            digits = Type.evaluate(el.visProp.digits),
+            digits = el.evalVisProp('digits'),
             unit = el.Unit(),
             val = el.Value(),
             i;
 
-        if (Type.evaluate(el.visProp.showprefix)) {
-            prefix = el.visProp.formatprefix.apply(el, [Type.evaluate(el.visProp.prefix)]);
+        if (el.evalVisProp('showprefix')) {
+            prefix = el.evalVisProp('prefix');
         }
-        if (Type.evaluate(el.visProp.showsuffix)) {
-            suffix = el.visProp.formatsuffix.apply(el, [Type.evaluate(el.visProp.suffix)]);
+        if (el.evalVisProp('showsuffix')) {
+            suffix = el.evalVisProp('suffix');
         }
 
         if (Type.isNumber(val)) {
@@ -455,14 +468,11 @@ JXG.createMeasurement = function (board, parents, attributes) {
             if (val.length === 2) {
                 val.unshift(undefined);
             }
-            val = el.visProp.formatcoords.apply(el, [val[1], val[2], val[0]]);
+            val = el.visProp.formatcoords(el, val[1], val[2], val[0]);
         }
 
         if (dim === 'direction' && Type.isArray(val)) {
-            if (val.length === 2) {
-                val.unshift(undefined);
-            }
-            val = el.visProp.formatdirection.apply(el, [val[1], val[2]]);
+            val = el.visProp.formatdirection(el, val[0], val[1]);
         }
 
         if (Type.isString(dim)) {
