@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -42,6 +42,14 @@ import Type from "../utils/type.js";
 
 /**
  * @class A circular sector is a subarea of the area enclosed by a circle. It is enclosed by two radii and an arc.
+ * <p>
+ * The sector as curve consists of two legs and an arc. The curve length is 6. That means, a point with coordinates
+ * [sector.X(t), sector.Y(t)] is on
+ * <ul>
+ * <li> leg 1 if t is between 0 and 1,
+ * <li> the arc if t is between 1 and 5,
+ * <li> leg 2 if t is between 5 and 6.
+ * </ul>
  * @pseudo
  * @name Sector
  * @augments JXG.Curve
@@ -58,7 +66,9 @@ import Type from "../utils/type.js";
  * <p>
  * Second possibility of input parameters are:
  * @param {JXG.Line_JXG.Line_array,number_array,number_number,function} line, line2, coords1 or direction1, coords2 or direction2, radius The sector is defined by two lines.
- * The two legs which define the sector are given by two coordinates arrays which are project initially two the two lines or by two directions (+/- 1).
+ * The two legs which define the sector are given by two coordinates arrays which are projected initially to the two lines or by
+ * two directions (+/- 1). If the two lines are parallel, two of the defining points on different lines have to coincide.
+ * This will be the center of the sector.
  * The last parameter is the radius of the sector.
  * <p>In this case, the sector will <b>not</b> have an arc as sub-object.
  *
@@ -181,9 +191,9 @@ JXG.createSector = function (board, parents, attributes) {
     var el,
         attr,
         i,
+        eps = 1.0e-14,
         type = "invalid",
-        s,
-        v,
+        s, v,
         attrPoints = ["center", "radiusPoint", "anglePoint"],
         points;
 
@@ -213,7 +223,8 @@ JXG.createSector = function (board, parents, attributes) {
     }
 
     attr = Type.copyAttributes(attributes, board.options, "sector");
-    el = board.create("curve", [[0], [0]], attr);
+    // The curve length is 6: 0-1: leg 1, 1-5: arc, 5-6: leg 2
+    el = board.create("curve", [[0], [0], 0, 6], attr);
     el.type = Const.OBJECT_TYPE_SECTOR;
     el.elType = "sector";
 
@@ -265,8 +276,26 @@ JXG.createSector = function (board, parents, attributes) {
         el.point2 = { visProp: {} };
         el.point3 = { visProp: {} };
 
-        /* Intersection point */
+        // Intersection point, just used locally for direction1 and  direction2
         s = Geometry.meetLineLine(el.line1.stdform, el.line2.stdform, 0, board);
+        if (Geometry.distance(s.usrCoords, [0, 0, 0], 3) < eps) {
+            // Parallel lines
+            if (
+                el.line1.point1.Dist(el.line2.point1) < eps ||
+                el.line1.point1.Dist(el.line2.point2) < eps
+            ) {
+                s = el.line1.point1.coords;
+            } else if (
+                el.line1.point2.Dist(el.line2.point1) < eps ||
+                el.line1.point2.Dist(el.line2.point1) < eps
+            ) {
+                s = el.line1.point2.coords;
+            } else {
+                console.log(
+                    "JSXGraph warning: Can't create Sector from parallel lines with no common defining point."
+                );
+            }
+        }
 
         if (Type.isArray(parents[2])) {
             /* project p1 to l1 */
@@ -329,8 +358,8 @@ JXG.createSector = function (board, parents, attributes) {
          */
         el.updateDataArray = function () {
             var r,
-                l1,
-                l2,
+                l1, l2,
+                eps = 1.0e-14,
                 A = [0, 0, 0],
                 B = [0, 0, 0],
                 C = [0, 0, 0],
@@ -341,8 +370,23 @@ JXG.createSector = function (board, parents, attributes) {
 
             // Intersection point of the lines
             B = Mat.crossProduct(l1.stdform, l2.stdform);
+            if (Geometry.distance(B, [0, 0, 0], 3) < eps) {
+                // Parallel lines
+                if (
+                    l1.point1.Dist(l2.point1) < eps ||
+                    l1.point1.Dist(l2.point2) < eps
+                ) {
+                    B = l1.point1.coords.usrCoords;
+                } else if (
+                    l1.point2.Dist(l2.point1) < eps ||
+                    l1.point2.Dist(l2.point1) < eps
+                ) {
+                    B = l1.point2.coords.usrCoords;
+                } else {
+                }
+            }
 
-            if (Math.abs(B[0]) > Mat.eps * Mat.eps) {
+            if (Math.abs(B[0]) > eps) {
                 B[1] /= B[0];
                 B[2] /= B[0];
                 B[0] /= B[0];
@@ -382,7 +426,7 @@ JXG.createSector = function (board, parents, attributes) {
         //
         // attr = Type.copyAttributes(attributes, board.options, "arc");
         // attr = Type.copyAttributes(attr, board.options, "sector", "arc");
-        // attr.withLabel = false;
+        // attr.withlabel = false;
         // attr.name += "_arc";
         // // el.arc = board.create("arc", [el.point1, el.point2, el.point3], attr);
         // // The arc's radius is always the radius of sector.
@@ -445,7 +489,7 @@ JXG.createSector = function (board, parents, attributes) {
         }
 
         // useDirection is necessary for circumCircleSectors
-        el.useDirection = attributes.usedirection;
+        el.useDirection = attributes.usedirection; // this makes the attribute immutable
         el.setParents(points);
 
         /**
@@ -471,17 +515,14 @@ JXG.createSector = function (board, parents, attributes) {
          * @ignore
          */
         el.updateDataArray = function () {
-            var ar,
-                det,
-                p0c,
-                p1c,
-                p2c,
+            var ar, det,
+                p0c, p1c, p2c,
                 A = this.point2,
                 B = this.point1,
                 C = this.point3,
                 phi,
                 sgn = 1,
-                vp_s = Type.evaluate(this.visProp.selection);
+                vp_s = this.evalVisProp('selection');
 
             if (!A.isReal || !B.isReal || !C.isReal) {
                 this.dataX = [NaN];
@@ -539,7 +580,7 @@ JXG.createSector = function (board, parents, attributes) {
 
     attr = Type.copyAttributes(attributes, board.options, "arc");
     attr = Type.copyAttributes(attr, board.options, "sector", "arc");
-    attr.withLabel = false;
+    attr.withlabel = false;
     // Minor or major arc:
     attr.selection = el.visProp.selection;
     attr.name += "_arc";
@@ -595,11 +636,11 @@ JXG.createSector = function (board, parents, attributes) {
             r = this.Radius(),
             dist = this.center.coords.distance(Const.COORDS_BY_USER, checkPoint),
             has,
-            vp_s = Type.evaluate(this.visProp.selection);
+            vp_s = this.evalVisProp('selection');
 
-        if (Type.isObject(Type.evaluate(this.visProp.precision))) {
+        if (Type.isObject(this.evalVisProp('precision'))) {
             type = this.board._inputDevice;
-            prec = Type.evaluate(this.visProp.precision[type]);
+            prec = this.evalVisProp('precision.' + type);
         } else {
             // 'inherit'
             prec = this.board.options.precision.hasPoint;
@@ -641,7 +682,7 @@ JXG.createSector = function (board, parents, attributes) {
             alpha,
             beta,
             has = dist < r,
-            vp_s = Type.evaluate(this.visProp.selection);
+            vp_s = this.evalVisProp('selection');
 
         if (has) {
             angle = Geometry.rad(this.radiuspoint, this.center, checkPoint.usrCoords.slice(1));
@@ -662,8 +703,8 @@ JXG.createSector = function (board, parents, attributes) {
 
     el.hasPoint = function (x, y) {
         if (
-            Type.evaluate(this.visProp.highlightonsector) ||
-            Type.evaluate(this.visProp.hasinnerpoints)
+            this.evalVisProp('highlightonsector') ||
+            this.evalVisProp('hasinnerpoints')
         ) {
             return this.hasPointSector(x, y);
         }
@@ -686,10 +727,9 @@ JXG.createSector = function (board, parents, attributes) {
      */
     el.getLabelAnchor = function () {
         var coords,
-            vec,
-            vecx,
-            vecy,
+            vec, vecx, vecy,
             len,
+            pos = this.label.evalVisProp('position'),
             angle = Geometry.rad(this.point2, this.point1, this.point3),
             dx = 13 / this.board.unitX,
             dy = 13 / this.board.unitY,
@@ -697,7 +737,7 @@ JXG.createSector = function (board, parents, attributes) {
             pmc = this.point1.coords.usrCoords,
             bxminusax = p2c[1] - pmc[1],
             byminusay = p2c[2] - pmc[2],
-            vp_s = Type.evaluate(this.visProp.selection),
+            vp_s = this.evalVisProp('selection'),
             l_vp = this.label ? this.label.visProp : this.visProp.label;
 
         // If this is uncommented, the angle label can not be dragged
@@ -705,30 +745,38 @@ JXG.createSector = function (board, parents, attributes) {
         //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
         //}
 
-        if ((vp_s === "minor" && angle > Math.PI) || (vp_s === "major" && angle < Math.PI)) {
-            angle = -(2 * Math.PI - angle);
+        if (
+            !Type.isString(pos) ||
+            (pos.indexOf('right') < 0 && pos.indexOf('left') < 0)
+        ) {
+
+            if ((vp_s === "minor" && angle > Math.PI) || (vp_s === "major" && angle < Math.PI)) {
+                angle = -(2 * Math.PI - angle);
+            }
+
+            coords = new Coords(
+                Const.COORDS_BY_USER,
+                [
+                    pmc[1] + Math.cos(angle * 0.5) * bxminusax - Math.sin(angle * 0.5) * byminusay,
+                    pmc[2] + Math.sin(angle * 0.5) * bxminusax + Math.cos(angle * 0.5) * byminusay
+                ],
+                this.board
+            );
+
+            vecx = coords.usrCoords[1] - pmc[1];
+            vecy = coords.usrCoords[2] - pmc[2];
+
+            len = Mat.hypot(vecx, vecy);
+            vecx = (vecx * (len + dx)) / len;
+            vecy = (vecy * (len + dy)) / len;
+            vec = [pmc[1] + vecx, pmc[2] + vecy];
+
+            l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
+
+            return new Coords(Const.COORDS_BY_USER, vec, this.board);
+        } else {
+            return this.getLabelPosition(pos, this.label.evalVisProp('distance'));
         }
-
-        coords = new Coords(
-            Const.COORDS_BY_USER,
-            [
-                pmc[1] + Math.cos(angle * 0.5) * bxminusax - Math.sin(angle * 0.5) * byminusay,
-                pmc[2] + Math.sin(angle * 0.5) * bxminusax + Math.cos(angle * 0.5) * byminusay
-            ],
-            this.board
-        );
-
-        vecx = coords.usrCoords[1] - pmc[1];
-        vecy = coords.usrCoords[2] - pmc[2];
-
-        len = Mat.hypot(vecx, vecy);
-        vecx = (vecx * (len + dx)) / len;
-        vecy = (vecy * (len + dy)) / len;
-        vec = [pmc[1] + vecx, pmc[2] + vecy];
-
-        l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
-
-        return new Coords(Const.COORDS_BY_USER, vec, this.board);
     };
 
     /**
@@ -872,8 +920,10 @@ JXG.createSector = function (board, parents, attributes) {
 JXG.registerElement("sector", JXG.createSector);
 
 /**
- * @class A circumcircle sector is different from a {@link Sector} mostly in the way the parent elements are interpreted.
- * At first, the circum center is determined from the three given points. Then the sector is drawn from <tt>p1</tt> through
+ * @class A sector whose arc is a circum circle arc through three points.
+ * A circumcircle sector is different from a {@link Sector} mostly in the way the parent elements are interpreted.
+ * At first, the circum center is determined from the three given points.
+ * Then the sector is drawn from <tt>p1</tt> through
  * <tt>p2</tt> to <tt>p3</tt>.
  * @pseudo
  * @name CircumcircleSector
@@ -944,7 +994,7 @@ JXG.createCircumcircleSector = function (board, parents, attributes) {
 JXG.registerElement("circumcirclesector", JXG.createCircumcircleSector);
 
 /**
- * @class A minor sector is a sector of a circle having measure less than or equal to
+ * @class A minor sector is a sector of a circle having measure at most
  * 180 degrees (pi radians). It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the sector.
  * @pseudo
@@ -1027,7 +1077,7 @@ JXG.createMinorSector = function (board, parents, attributes) {
 JXG.registerElement("minorsector", JXG.createMinorSector);
 
 /**
- * @class A major sector is a sector of a circle having measure greater than or equal to
+ * @class A major sector is a sector of a circle having measure at least
  * 180 degrees (pi radians). It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the sector.
  * @pseudo
@@ -1065,15 +1115,18 @@ JXG.createMajorSector = function (board, parents, attributes) {
 JXG.registerElement("majorsector", JXG.createMajorSector);
 
 /**
- * @class The angle element is used to denote an angle defined by three points. Visually it is just a {@link Sector}
+ * @class Angle sector defined by three points or two lines.
+ * Visually it is just a {@link Sector}
  * element with a radius not defined by the parent elements but by an attribute <tt>radius</tt>. As opposed to the sector,
  * an angle has two angle points and no radius point.
  * Sector is displayed if type=="sector".
  * If type=="square", instead of a sector a parallelogram is displayed.
- * In case of type=="auto", a square is displayed if the angle is near orthogonal.
+ * In case of type=="auto", a square is displayed if the angle is near orthogonal. The precision
+ * to decide if an angle is orthogonal is determined by the attribute
+ * {@link Angle#orthoSensitivity}.
  * <p>
  * If no name is provided the angle label is automatically set to a lower greek letter. If no label should be displayed use
- * the attribute <tt>withLabel:false</tt>.
+ * the attribute <tt>withLabel:false</tt> or set the name attribute to the empty string.
  *
  * @pseudo
  * @name Angle
@@ -1245,6 +1298,7 @@ JXG.createAngle = function (board, parents, attributes) {
 
     board.suspendUpdate(); // Necessary for immediate availability of radius.
     if (type === "2lines") {
+        // Angle defined by two lines
         parents.push(radius);
         el = board.create("sector", parents, attr);
         /**
@@ -1265,6 +1319,7 @@ JXG.createAngle = function (board, parents, attributes) {
          */
         el.free = function (val) {};
     } else {
+        // Angle defined by three points
         el = board.create("sector", [points[1], points[0], points[2]], attr);
         el.arc.visProp.priv = true;
 
@@ -1311,7 +1366,7 @@ JXG.createAngle = function (board, parents, attributes) {
                 ar,
                 phi,
                 sgn = 1,
-                vp_s = Type.evaluate(this.visProp.selection);
+                vp_s = this.evalVisProp('selection');
 
             phi = Geometry.rad(A, B, C);
             if ((vp_s === "minor" && phi > Math.PI) || (vp_s === "major" && phi < Math.PI)) {
@@ -1472,7 +1527,8 @@ JXG.createAngle = function (board, parents, attributes) {
                 });
                 p.coords.on("update", function () {
                     t2.update();
-                    q.moveTo(Mat.matVecMult(t2.matrix, p.coords.usrCoords));
+                    // q.moveTo(Mat.matVecMult(t2.matrix, p.coords.usrCoords));
+                    q.setPositionDirectly(Const.COORDS_BY_USER, Mat.matVecMult(t2.matrix, p.coords.usrCoords));
                 });
 
                 p.setParents(q);
@@ -1512,7 +1568,7 @@ JXG.createAngle = function (board, parents, attributes) {
 
     // GEONExT compatible labels.
     if (Type.exists(el.visProp.text)) {
-        el.label.setText(Type.evaluate(el.visProp.text));
+        el.label.setText(el.evalVisProp('text'));
     }
 
     el.elType = "angle";
@@ -1578,26 +1634,30 @@ JXG.createAngle = function (board, parents, attributes) {
      * @ignore
      */
     el.updateDataArray = function () {
-        var type = Type.evaluate(this.visProp.type),
+        var type = this.evalVisProp('type'),
             deg = Geometry.trueAngle(this.point2, this.point1, this.point3),
-            vp_s = Type.evaluate(this.visProp.selection);
+            vp_s = this.evalVisProp('selection');
 
         if ((vp_s === "minor" && deg > 180.0) || (vp_s === "major" && deg < 180.0)) {
             deg = 360.0 - deg;
         }
 
-        if (Math.abs(deg - 90.0) < Type.evaluate(this.visProp.orthosensitivity) + Mat.eps) {
-            type = Type.evaluate(this.visProp.orthotype);
+        if (Math.abs(deg - 90.0) < this.evalVisProp('orthosensitivity') + Mat.eps) {
+            type = this.evalVisProp('orthotype');
         }
 
         if (type === "none") {
             this.updateDataArrayNone();
+            this.maxX = function() { return 0; };
         } else if (type === "square") {
             this.updateDataArraySquare();
+            this.maxX = function() { return 4; };
         } else if (type === "sector") {
             this.updateDataArraySector();
+            this.maxX = function() { return 6; };
         } else if (type === "sectordot") {
             this.updateDataArraySector();
+            this.maxX = function() { return 6; };
             if (!this.dot.visProp.visible) {
                 this.dot.setAttribute({ visible: true });
             }
@@ -1633,7 +1693,7 @@ JXG.createAngle = function (board, parents, attributes) {
                 d = Geometry.distance(A, B, 3);
                 a2 = Geometry.rad(el.point2, el.point1, el.point3);
 
-                vp_s = Type.evaluate(el.visProp.selection);
+                vp_s = el.evalVisProp('selection');
                 if ((vp_s === "minor" && a2 > Math.PI) || (vp_s === "major" && a2 < Math.PI)) {
                     a2 = -(2 * Math.PI - a2);
                 }
@@ -1733,7 +1793,8 @@ JXG.createAngle = function (board, parents, attributes) {
         var vec,
             dx = 12,
             A, B, r, d, a2, co, si, mat,
-            vp_s = Type.evaluate(el.visProp.selection),
+            vp_s = el.evalVisProp('selection'),
+            pos = this.label.evalVisProp('position'),
             l_vp = this.label ? this.label.visProp : this.visProp.label;
 
         // If this is uncommented, the angle label can not be dragged
@@ -1741,45 +1802,53 @@ JXG.createAngle = function (board, parents, attributes) {
         //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
         //}
 
-        if (Type.exists(this.label) && Type.exists(this.label.visProp.fontsize)) {
-            dx = Type.evaluate(this.label.visProp.fontsize);
+        if (
+            !Type.isString(pos) ||
+            (pos.indexOf('right') < 0 && pos.indexOf('left') < 0)
+        ) {
+
+            if (Type.exists(this.label) && Type.exists(this.label.visProp.fontsize)) {
+                dx = this.label.evalVisProp('fontsize');
+            }
+            dx /= this.board.unitX;
+
+            A = el.point2.coords.usrCoords;
+            B = el.point1.coords.usrCoords;
+            r = el.Radius();
+            d = Geometry.distance(A, B, 3);
+            a2 = Geometry.rad(el.point2, el.point1, el.point3);
+            if ((vp_s === "minor" && a2 > Math.PI) || (vp_s === "major" && a2 < Math.PI)) {
+                a2 = -(2 * Math.PI - a2);
+            }
+            a2 *= 0.5;
+            co = Math.cos(a2);
+            si = Math.sin(a2);
+
+            A = [1, B[1] + ((A[1] - B[1]) * r) / d, B[2] + ((A[2] - B[2]) * r) / d];
+
+            mat = [
+                [1, 0, 0],
+                [B[1] - 0.5 * B[1] * co + 0.5 * B[2] * si, co * 0.5, -si * 0.5],
+                [B[2] - 0.5 * B[1] * si - 0.5 * B[2] * co, si * 0.5, co * 0.5]
+            ];
+            vec = Mat.matVecMult(mat, A);
+            vec[1] /= vec[0];
+            vec[2] /= vec[0];
+            vec[0] /= vec[0];
+
+            d = Geometry.distance(vec, B, 3);
+            vec = [
+                vec[0],
+                B[1] + ((vec[1] - B[1]) * (r + dx)) / d,
+                B[2] + ((vec[2] - B[2]) * (r + dx)) / d
+            ];
+
+            l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
+
+            return new Coords(Const.COORDS_BY_USER, vec, this.board);
+        } else {
+            return this.getLabelPosition(pos, this.label.evalVisProp('distance'));
         }
-        dx /= this.board.unitX;
-
-        A = el.point2.coords.usrCoords;
-        B = el.point1.coords.usrCoords;
-        r = el.Radius();
-        d = Geometry.distance(A, B, 3);
-        a2 = Geometry.rad(el.point2, el.point1, el.point3);
-        if ((vp_s === "minor" && a2 > Math.PI) || (vp_s === "major" && a2 < Math.PI)) {
-            a2 = -(2 * Math.PI - a2);
-        }
-        a2 *= 0.5;
-        co = Math.cos(a2);
-        si = Math.sin(a2);
-
-        A = [1, B[1] + ((A[1] - B[1]) * r) / d, B[2] + ((A[2] - B[2]) * r) / d];
-
-        mat = [
-            [1, 0, 0],
-            [B[1] - 0.5 * B[1] * co + 0.5 * B[2] * si, co * 0.5, -si * 0.5],
-            [B[2] - 0.5 * B[1] * si - 0.5 * B[2] * co, si * 0.5, co * 0.5]
-        ];
-        vec = Mat.matVecMult(mat, A);
-        vec[1] /= vec[0];
-        vec[2] /= vec[0];
-        vec[0] /= vec[0];
-
-        d = Geometry.distance(vec, B, 3);
-        vec = [
-            vec[0],
-            B[1] + ((vec[1] - B[1]) * (r + dx)) / d,
-            B[2] + ((vec[2] - B[2]) * (r + dx)) / d
-        ];
-
-        l_vp.position = Geometry.calcLabelQuadrant(Geometry.rad([1, 0], [0, 0], vec));
-
-        return new Coords(Const.COORDS_BY_USER, vec, this.board);
     };
 
     el.methodMap = Type.deepCopy(el.methodMap, {
@@ -1794,7 +1863,7 @@ JXG.createAngle = function (board, parents, attributes) {
 JXG.registerElement("angle", JXG.createAngle);
 
 /**
- * @class A non-reflex angle is the acute or obtuse instance of an angle.
+ * @class A non-reflex angle is the instance of an angle that is at most 180°.
  * It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the sector.
  * @pseudo
@@ -1850,7 +1919,7 @@ JXG.createNonreflexAngle = function (board, parents, attributes) {
 JXG.registerElement("nonreflexangle", JXG.createNonreflexAngle);
 
 /**
- * @class A reflex angle is the neither acute nor obtuse instance of an angle.
+ * @class A reflex angle is the instance of an angle that is larger than 180°.
  * It is defined by a center, one point that
  * defines the radius, and a third point that defines the angle of the sector.
  * @pseudo
