@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -38,25 +38,25 @@
  * a board.
  */
 
-import JXG from "../jxg";
-import Mat from "../math/math";
-import Const from "../base/constants";
-import Coords from "../base/coords";
-import Type from "../utils/type";
-import Point from "../base/point";
+import JXG from "../jxg.js";
+import Mat from "../math/math.js";
+import Const from "../base/constants.js";
+import Coords from "../base/coords.js";
+import Type from "../utils/type.js";
+import Point from "../base/point.js";
 
 /**
  * @class A slider can be used to choose values from a given range of numbers.
  * @pseudo
- * @description
  * @name Slider
  * @augments Glider
  * @constructor
  * @type JXG.Point
  * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
- * @param {Array_Array_Array} start,end,data The first two arrays give the start and the end where the slider is drawn
+ * @param {Array_Array_Array} start,end,range The first two arrays give the start and the end where the slider is drawn
  * on the board. The third array gives the start and the end of the range the slider operates as the first resp. the
  * third component of the array. The second component of the third array gives its start value.
+ *
  * @example
  * // Create a slider with values between 1 and 10, initial position is 5.
  * var s = board.create('slider', [[1, 2], [3, 2], [1, 5, 10]]);
@@ -160,14 +160,39 @@ import Point from "../base/point";
  *
  * </script><pre>
  *
+ * @example
+ * // Create a "frozen" slider
+ * var sli = board.create('slider', [[-4, 4], [-1.5, 4], [-10, 1, 10]], {
+ *     name:'a',
+ *     point1: {frozen: true},
+ *     point2: {frozen: true}
+ * });
+ *
+ * </pre><div id="JXG23afea4f-2e91-4006-a505-2895033cf1fc" class="jxgbox" style="width: 300px; height: 300px;"></div>
+ * <script type="text/javascript">
+ *     (function() {
+ *         var board = JXG.JSXGraph.initBoard('JXG23afea4f-2e91-4006-a505-2895033cf1fc',
+ *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+ *     var sli = board.create('slider', [[-4, 4], [-1.5, 4], [-10, 1, 10]], {
+ *         name:'a',
+ *         point1: {frozen: true},
+ *         point2: {frozen: true}
+ *     });
+ *
+ *     })();
+ *
+ * </script><pre>
+ *
+ *
  */
 JXG.createSlider = function (board, parents, attributes) {
     var pos0, pos1,
-        smin, start, smax, sdiff,
+        smin, start, smax, diff,
         p1, p2, p3, l1, l2,
         ticks, ti, t,
         startx, starty,
         withText, withTicks,
+        snapValues, snapValueDistance,
         snapWidth, sw, s,
         attr;
 
@@ -175,19 +200,18 @@ JXG.createSlider = function (board, parents, attributes) {
     withTicks = attr.withticks;
     withText = attr.withlabel;
     snapWidth = attr.snapwidth;
+    snapValues = attr.snapvalues;
+    snapValueDistance = attr.snapvaluedistance;
 
-    // start point
-    attr = Type.copyAttributes(attributes, board.options, "slider", "point1");
-    p1 = board.create("point", parents[0], attr);
+    // Start point
+    p1 = board.create("point", parents[0], attr.point1);
 
-    // end point
-    attr = Type.copyAttributes(attributes, board.options, "slider", "point2");
-    p2 = board.create("point", parents[1], attr);
+    // End point
+    p2 = board.create("point", parents[1], attr.point2);
     //g = board.create('group', [p1, p2]);
 
     // Base line
-    attr = Type.copyAttributes(attributes, board.options, "slider", "baseline");
-    l1 = board.create("segment", [p1, p2], attr);
+    l1 = board.create("segment", [p1, p2], attr.baseline);
 
     // This is required for a correct projection of the glider onto the segment below
     l1.updateStdform();
@@ -197,25 +221,28 @@ JXG.createSlider = function (board, parents, attributes) {
     smin = parents[2][0];
     start = parents[2][1];
     smax = parents[2][2];
-    sdiff = smax - smin;
+    diff = smax - smin;
 
     sw = Type.evaluate(snapWidth);
-    s = sw === -1 ? start : Math.round(start / sw) * sw;
+    s = sw === -1 ?
+        start :
+        Math.round((start - smin)/ sw) * sw + smin;
+        // Math.round(start / sw) * sw;
     startx = pos0[0] + ((pos1[0] - pos0[0]) * (s - smin)) / (smax - smin);
     starty = pos0[1] + ((pos1[1] - pos0[1]) * (s - smin)) / (smax - smin);
 
     // glider point
-    attr = Type.copyAttributes(attributes, board.options, "slider");
+    // attr = Type.copyAttributes(attributes, board.options, "slider");
     // overwrite this in any case; the sliders label is a special text element, not the gliders label.
     // this will be set back to true after the text was created (and only if withlabel was true initially).
-    attr.withLabel = false;
+    attr.withlabel = false;
     // gliders set snapwidth=-1 by default (i.e. deactivate them)
     p3 = board.create("glider", [startx, starty, l1], attr);
-    p3.setAttribute({ snapwidth: snapWidth });
+    p3.setAttribute({ snapwidth: snapWidth, snapvalues: snapValues, snapvaluedistance: snapValueDistance });
 
     // Segment from start point to glider point: highline
-    attr = Type.copyAttributes(attributes, board.options, "slider", "highline");
-    l2 = board.create("segment", [p1, p3], attr);
+    // attr = Type.copyAttributes(attributes, board.options, "slider", "highline");
+    l2 = board.create("segment", [p1, p3], attr.highline);
 
     /**
      * Returns the current slider value.
@@ -225,21 +252,29 @@ JXG.createSlider = function (board, parents, attributes) {
      * @returns {Number}
      */
     p3.Value = function () {
-        var sdiff = this._smax - this._smin,
-            ev_sw = Type.evaluate(this.visProp.snapwidth);
+        var d = this._smax - this._smin,
+            ev_sw = this.evalVisProp('snapwidth');
 
         return ev_sw === -1
-            ? this.position * sdiff + this._smin
-            : Math.round((this.position * sdiff + this._smin) / ev_sw) * ev_sw;
+            ? this.position * d + this._smin
+            : Math.round((this.position * d) / ev_sw) * ev_sw  + this._smin;
     };
 
     p3.methodMap = Type.deepCopy(p3.methodMap, {
         Value: "Value",
         setValue: "setValue",
         smax: "_smax",
+        // Max: "_smax",
         smin: "_smin",
+        // Min: "_smin",
         setMax: "setMax",
-        setMin: "setMin"
+        setMin: "setMin",
+        point1: "point1",
+        point2: "point2",
+        baseline: "baseline",
+        highline: "highline",
+        ticks: "ticks",
+        label: "label"
     });
 
     /**
@@ -281,10 +316,10 @@ JXG.createSlider = function (board, parents, attributes) {
      * @returns {Object} this object
      */
     p3.setValue = function (val) {
-        var sdiff = this._smax - this._smin;
+        var d = this._smax - this._smin;
 
-        if (Math.abs(sdiff) > Mat.eps) {
-            this.position = (val - this._smin) / sdiff;
+        if (Math.abs(d) > Mat.eps) {
+            this.position = (val - this._smin) / d;
         } else {
             this.position = 0.0; //this._smin;
         }
@@ -306,51 +341,51 @@ JXG.createSlider = function (board, parents, attributes) {
     };
 
     if (withText) {
-        attr = Type.copyAttributes(attributes, board.options, 'slider', 'label');
+        // attr = Type.copyAttributes(attributes, board.options, 'slider', 'label');
         t = board.create('text', [
-                function () {
-                    return (p2.X() - p1.X()) * 0.05 + p2.X();
-                },
-                function () {
-                    return (p2.Y() - p1.Y()) * 0.05 + p2.Y();
-                },
-                function () {
-                    var n,
-                        d = Type.evaluate(p3.visProp.digits),
-                        sl = Type.evaluate(p3.visProp.suffixlabel),
-                        ul = Type.evaluate(p3.visProp.unitlabel),
-                        pl = Type.evaluate(p3.visProp.postlabel);
+            function () {
+                return (p2.X() - p1.X()) * 0.05 + p2.X();
+            },
+            function () {
+                return (p2.Y() - p1.Y()) * 0.05 + p2.Y();
+            },
+            function () {
+                var n,
+                    d = p3.evalVisProp('digits'),
+                    sl = p3.evalVisProp('suffixlabel'),
+                    ul = p3.evalVisProp('unitlabel'),
+                    pl = p3.evalVisProp('postlabel');
 
-                    if (d === 2 && Type.evaluate(p3.visProp.precision) !== 2) {
-                        // Backwards compatibility
-                        d = Type.evaluate(p3.visProp.precision);
-                    }
-
-                    if (sl !== null) {
-                        n = sl;
-                    } else if (p3.name && p3.name !== "") {
-                        n = p3.name + " = ";
-                    } else {
-                        n = "";
-                    }
-
-                    if (p3.useLocale()) {
-                        n += p3.formatNumberLocale(p3.Value(), d);
-                    } else {
-                        n += Type.toFixed(p3.Value(), d);
-                    }
-
-                    if (ul !== null) {
-                        n += ul;
-                    }
-                    if (pl !== null) {
-                        n += pl;
-                    }
-
-                    return n;
+                if (d === 2 && p3.evalVisProp('precision') !== 2) {
+                    // Backwards compatibility
+                    d = p3.evalVisProp('precision');
                 }
-            ],
-            attr
+
+                if (sl !== null) {
+                    n = sl;
+                } else if (p3.name && p3.name !== "") {
+                    n = p3.name + " = ";
+                } else {
+                    n = "";
+                }
+
+                if (p3.useLocale()) {
+                    n += p3.formatNumberLocale(p3.Value(), d);
+                } else {
+                    n += Type.toFixed(p3.Value(), d);
+                }
+
+                if (ul !== null) {
+                    n += ul;
+                }
+                if (pl !== null) {
+                    n += pl;
+                }
+
+                return n;
+            }
+        ],
+            attr.label
         );
 
         /**
@@ -401,9 +436,9 @@ JXG.createSlider = function (board, parents, attributes) {
     if (withTicks) {
         // Function to generate correct label texts
 
-        attr = Type.copyAttributes(attributes, board.options, "slider", "ticks");
+        // attr = Type.copyAttributes(attributes, board.options, "slider", "ticks");
         if (!Type.exists(attr.generatelabeltext)) {
-            attr.generateLabelText = function (tick, zero, value) {
+            attr.ticks.generateLabelText = function (tick, zero, value) {
                 var labelText,
                     dFull = p3.point1.Dist(p3.point2),
                     smin = p3._smin,
@@ -434,10 +469,10 @@ JXG.createSlider = function (board, parents, attributes) {
                         return 0;
                     }
 
-                    return (d / dFull) * sdiff + smin;
+                    return (d / dFull) * diff + smin;
                 }
             ],
-            attr
+            attr.ticks
         );
 
         /**
@@ -471,6 +506,7 @@ JXG.createSlider = function (board, parents, attributes) {
         t.dump = false;
     }
 
+    // p3.type = Const.OBJECT_TYPE_SLIDER; // No! type has to be Const.OBJECT_TYPE_GLIDER
     p3.elType = "slider";
     p3.parents = parents;
     p3.subs = {
@@ -480,6 +516,9 @@ JXG.createSlider = function (board, parents, attributes) {
         highLine: l2
     };
     p3.inherits.push(p1, p2, l1, l2);
+    // Remove inherits to avoid circular inherits.
+    l1.inherits = [];
+    l2.inherits = [];
 
     if (withTicks) {
         ti.dump = false;
@@ -498,7 +537,7 @@ JXG.createSlider = function (board, parents, attributes) {
     p3.baseline.on("up", function (evt) {
         var pos, c;
 
-        if (Type.evaluate(p3.visProp.moveonup) && !Type.evaluate(p3.visProp.fixed)) {
+        if (p3.evalVisProp('moveonup') && !p3.evalVisProp('fixed')) {
             pos = l1.board.getMousePosition(evt, 0);
             c = new Coords(Const.COORDS_BY_SCREEN, pos, this.board);
             p3.moveTo([c.usrCoords[1], c.usrCoords[2]]);
@@ -506,34 +545,6 @@ JXG.createSlider = function (board, parents, attributes) {
         }
     });
 
-    // Save the visibility attribute of the sub-elements
-    // for (el in p3.subs) {
-    //     p3.subs[el].status = {
-    //         visible: p3.subs[el].visProp.visible
-    //     };
-    // }
-
-    // p3.hideElement = function () {
-    //     var el;
-    //     GeometryElement.prototype.hideElement.call(this);
-    //
-    //     for (el in this.subs) {
-    //         // this.subs[el].status.visible = this.subs[el].visProp.visible;
-    //         this.subs[el].hideElement();
-    //     }
-    // };
-
-    //         p3.showElement = function () {
-    //             var el;
-    //             GeometryElement.prototype.showElement.call(this);
-    //
-    //             for (el in this.subs) {
-    // //                if (this.subs[el].status.visible) {
-    //                 this.subs[el].showElement();
-    // //                }
-    //             }
-    //         };
-
     // This is necessary to show baseline, highline and ticks
     // when opening the board in case the visible attributes are set
     // to 'inherit'.
