@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Carsten Miller,
         Alfred Wassermann
@@ -38,8 +38,10 @@ import Const from "../base/constants.js";
 import Type from "../utils/type.js";
 
 /**
- * @class Smart label. These are customized text elements for displaying measurements of JSXGraph elements, like length of a
- * segment, perimeter or area of a circle or polygon (including polygonal chain), slope of a line, value of an angle, and coordinates of a point.
+ * @class Customized text elements for displaying measurements of JSXGraph elements,
+ * Examples are length of a
+ * segment, perimeter or area of a circle or polygon (including polygonal chain),
+ * slope of a line, value of an angle, and coordinates of a point.
  * <p>
  * If additionally a text, or a function is supplied and the content is not the empty string,
  * that text is displayed instead of the measurement.
@@ -311,11 +313,11 @@ JXG.createSmartLabel = function (board, parents, attributes) {
             var str = '',
                 val,
                 txt = Type.evaluate(user_supplied_text),
-                digits = Type.evaluate(el.visProp.digits),
-                u = Type.evaluate(el.visProp.unit),
-                pre = Type.evaluate(el.visProp.prefix),
-                suf = Type.evaluate(el.visProp.suffix),
-                mj = Type.evaluate(el.visProp.usemathjax) || Type.evaluate(el.visProp.usekatex);
+                digits = el.evalVisProp('digits'),
+                u = el.evalVisProp('unit'),
+                pre = el.evalVisProp('prefix'),
+                suf = el.evalVisProp('suffix'),
+                mj = el.evalVisProp('usemathjax') || el.evalVisProp('usekatex');
 
             if (txt === '') {
                 if (el.useLocale()) {
@@ -345,12 +347,12 @@ JXG.createSmartLabel = function (board, parents, attributes) {
         txt_fun = function () {
             var str = '',
                 txt = Type.evaluate(user_supplied_text),
-                digits = Type.evaluate(el.visProp.digits),
-                u = Type.evaluate(el.visProp.unit),
-                pre = Type.evaluate(el.visProp.prefix),
-                suf = Type.evaluate(el.visProp.suffix),
-                dir = Type.evaluate(el.visProp.dir),
-                mj = Type.evaluate(el.visProp.usemathjax) || Type.evaluate(el.visProp.usekatex),
+                digits = el.evalVisProp('digits'),
+                u = el.evalVisProp('unit'),
+                pre = el.evalVisProp('prefix'),
+                suf = el.evalVisProp('suffix'),
+                dir = el.evalVisProp('dir'),
+                mj = el.evalVisProp('usemathjax') || el.evalVisProp('usekatex'),
                 x, y;
 
             if (el.useLocale()) {
