@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -272,23 +272,22 @@ JXG.Math = {
     },
 
     /**
-     * Multiplies a vector vec to a matrix mat: mat * vec. The matrix is interpreted by this function as an array of rows. Please note: This
+     * Multiplies a vector vec to a matrix mat: mat * vec. The matrix is interpreted by this function as an array of rows.
+     * Please note: This
      * function does not check if the dimensions match.
-     * @param {Array} mat Two dimensional array of numbers. The inner arrays describe the columns, the outer ones the matrix' rows.
+     * @param {Array} mat Two-dimensional array of numbers. The inner arrays describe the columns, the outer ones the matrix' rows.
      * @param {Array} vec Array of numbers
      * @returns {Array} Array of numbers containing the result
      * @example
      * var A = [[2, 1],
-     *          [1, 3]],
+     *          [2, 3]],
      *     b = [4, 5],
      *     c;
-     * c = JXG.Math.matVecMult(A, b)
-     * // c === [13, 19];
+     * c = JXG.Math.matVecMult(A, b);
+     * // c === [13, 23];
      */
     matVecMult: function (mat, vec) {
-        var i,
-            s,
-            k,
+        var i, k, s,
             m = mat.length,
             n = vec.length,
             res = [];
@@ -310,16 +309,53 @@ JXG.Math = {
     },
 
     /**
-     * Computes the product of the two matrices mat1*mat2.
-     * @param {Array} mat1 Two dimensional array of numbers
-     * @param {Array} mat2 Two dimensional array of numbers
-     * @returns {Array} Two dimensional Array of numbers containing result
+     * Multiplies a vector vec to a matrix mat from the left: vec * mat.
+     * The matrix is interpreted by this function as an array of rows.
+     * Please note: This function does not check if the dimensions match.
+     * @param {Array} vec Array of numbers
+     * @param {Array} mat Two-dimensional array of numbers. The inner arrays describe the columns,
+     *  the outer ones the matrix' rows.
+     * @returns {Array} Array of numbers containing the result
+     * @example
+     * var A = [[2, 1],
+     *          [2, 3]],
+     *     b = [4, 5],
+     *     c;
+     * c = JXG.Math.vecMatMult(b, A);
+     * // c === [18, 16];
+     */
+    vecMatMult: function (vec, mat) {
+        var i, k, s,
+            m = mat.length,
+            n = vec.length,
+            res = [];
+
+        if (n === 3) {
+            for (i = 0; i < m; i++) {
+                res[i] = vec[0] * mat[0][i] + vec[1] * mat[1][i] + vec[2] * mat[2][i];
+            }
+        } else {
+            for (i = 0; i < n; i++) {
+                s = 0;
+                for (k = 0; k < m; k++) {
+                    s += vec[k] * mat[k][i];
+                }
+                res[i] = s;
+            }
+        }
+        return res;
+    },
+
+    /**
+     * Computes the product of the two matrices: mat1 * mat2.
+     * Returns a new matrix array.
+     *
+     * @param {Array} mat1 Two-dimensional array of numbers
+     * @param {Array} mat2 Two-dimensional array of numbers
+     * @returns {Array} Two-dimensional Array of numbers containing result
      */
     matMatMult: function (mat1, mat2) {
-        var i,
-            j,
-            s,
-            k,
+        var i, j, s, k,
             m = mat1.length,
             n = m > 0 ? mat2[0].length : 0,
             m2 = mat2.length,
@@ -338,7 +374,50 @@ JXG.Math = {
     },
 
     /**
-     * Transposes a matrix given as a two dimensional array.
+     * Multiply a matrix mat by a scalar alpha: mat * scalar
+     *
+     * @param {Array} mat Two-dimensional array of numbers
+     * @param {Number} alpha Scalar
+     * @returns {Array} Two-dimensional Array of numbers containing result
+     */
+    matNumberMult: function (mat, alpha) {
+        var i, j,
+            m = mat.length,
+            n = m > 0 ? mat[0].length : 0,
+            res = this.matrix(m, n);
+
+        for (i = 0; i < m; i++) {
+            for (j = 0; j < n; j++) {
+                res[i][j] = mat[i][j] * alpha;
+            }
+        }
+        return res;
+    },
+
+    /**
+     * Compute the sum of two matrices: mat1 + mat2.
+     * Returns a new matrix object.
+     *
+     * @param {Array} mat1 Two-dimensional array of numbers
+     * @param {Array} mat2 Two-dimensional array of numbers
+     * @returns {Array} Two-dimensional Array of numbers containing result
+     */
+    matMatAdd: function (mat1, mat2) {
+        var i, j,
+            m = mat1.length,
+            n = m > 0 ? mat1[0].length : 0,
+            res = this.matrix(m, n);
+
+        for (i = 0; i < m; i++) {
+            for (j = 0; j < n; j++) {
+                res[i][j] = mat1[i][j] + mat2[i][j];
+            }
+        }
+        return res;
+    },
+
+    /**
+     * Transposes a matrix given as a two-dimensional array.
      * @param {Array} M The matrix to be transposed
      * @returns {Array} The transpose of M
      */
@@ -361,18 +440,15 @@ JXG.Math = {
     },
 
     /**
-     * Compute the inverse of an nxn matrix with Gauss elimination.
-     * @param {Array} Ain
-     * @returns {Array} Inverse matrix of Ain
+     * Compute the inverse of an <i>(n x n)</i>-matrix by Gauss elimination.
+     *
+     * @param {Array} A matrix
+     * @returns {Array} Inverse matrix of A or empty array (i.e. []) in case A is singular.
      */
     inverse: function (Ain) {
-        var i,
-            j,
-            k,
-            s,
-            ma,
-            r,
-            swp,
+        var i, j, k, r, s,
+            eps = this.eps * this.eps,
+            ma, swp,
             n = Ain.length,
             A = [],
             p = [],
@@ -387,7 +463,7 @@ JXG.Math = {
         }
 
         for (j = 0; j < n; j++) {
-            // pivot search:
+            // Pivot search
             ma = Math.abs(A[j][j]);
             r = j;
 
@@ -399,7 +475,8 @@ JXG.Math = {
             }
 
             // Singular matrix
-            if (ma <= this.eps) {
+            if (ma <= eps) {
+                JXG.warn('JXG.Math.inverse: singular matrix');
                 return [];
             }
 
@@ -448,6 +525,29 @@ JXG.Math = {
         return A;
     },
 
+    /**
+     * Trace of a square matrix, given as a two-dimensional array.
+     * @param {Array} M Square matrix
+     * @returns {Number} The trace of M, NaN if M is not square.
+     */
+    trace: function (M) {
+        var i, m, n,
+            t = 0.0;
+
+        // number of rows of M
+        m = M.length;
+        // number of columns of M
+        n = M.length > 0 ? M[0].length : 0;
+        if (m !== n) {
+            return NaN;
+        }
+        for (i = 0; i < n; i++) {
+            t += M[i][i];
+        }
+
+        return t;
+    },
+
     /**
      * Inner product of two vectors a and b. n is the length of the vectors.
      * @param {Array} a Vector
@@ -517,7 +617,7 @@ JXG.Math = {
      * @param {Number} a
      * @param {Array} x
      * @param {Array} y
-     * @returns
+     * @returns {Array}
      */
     axpy: function (a, x, y) {
         var i,
@@ -607,7 +707,7 @@ JXG.Math = {
 
     /**
      * Hyperbolic arc-cosine of a number.
-     *
+     * @function
      * @param {Number} x
      * @returns {Number}
      */
@@ -619,6 +719,7 @@ JXG.Math = {
 
     /**
      * Hyperbolic arcsine of a number
+     * @function
      * @param {Number} x
      * @returns {Number}
      */
@@ -841,7 +942,7 @@ JXG.Math = {
 
     /**
      * Greatest common divisor (gcd) of two numbers.
-     * @see <a href="https://rosettacode.org/wiki/Greatest_common_divisor#JavaScript">rosettacode.org</a>
+     * See {@link <a href="https://rosettacode.org/wiki/Greatest_common_divisor#JavaScript">rosettacode.org</a>}.
      *
      * @param  {Number} a First number
      * @param  {Number} b Second number
@@ -947,7 +1048,7 @@ JXG.Math = {
     /**
      *  Error function, see {@link https://en.wikipedia.org/wiki/Error_function}.
      *
-     * @see JXG.Math.PropFunc.erf
+     * @see JXG.Math.ProbFuncs.erf
      * @param  {Number} x
      * @returns {Number}
      */
@@ -959,7 +1060,7 @@ JXG.Math = {
      * Complementary error function, i.e. 1 - erf(x).
      *
      * @see JXG.Math.erf
-     * @see JXG.Math.PropFunc.erfc
+     * @see JXG.Math.ProbFuncs.erfc
      * @param  {Number} x
      * @returns {Number}
      */
@@ -971,7 +1072,7 @@ JXG.Math = {
      * Inverse of error function
      *
      * @see JXG.Math.erf
-     * @see JXG.Math.PropFunc.erfi
+     * @see JXG.Math.ProbFuncs.erfi
      * @param  {Number} x
      * @returns {Number}
      */
@@ -982,7 +1083,7 @@ JXG.Math = {
     /**
      * Normal distribution function
      *
-     * @see JXG.Math.PropFunc.ndtr
+     * @see JXG.Math.ProbFuncs.ndtr
      * @param  {Number} x
      * @returns {Number}
      */
@@ -994,7 +1095,7 @@ JXG.Math = {
      * Inverse of normal distribution function
      *
      * @see JXG.Math.ndtr
-     * @see JXG.Math.PropFunc.ndtri
+     * @see JXG.Math.ProbFuncs.ndtri
      * @param  {Number} x
      * @returns {Number}
      */
@@ -1194,7 +1295,7 @@ JXG.Math = {
      * @param {Number} x Number which is to be converted
      * @param {Number} [order=0.001] Small number determining the approximation precision.
      * @returns {Array} [sign, leading, nominator, denominator] where sign is 1 or -1.
-     * @see JXG#toFraction
+     * @see JXG.toFraction
      *
      * @example
      * JXG.Math.decToFraction(0.33333333);
@@ -1293,9 +1394,9 @@ JXG.Math = {
     },
 
     /**
-     * Converts a two dimensional array to a one dimensional Float32Array that can be processed by WebGL.
-     * @param {Array} m A matrix in a two dimensional array.
-     * @returns {Float32Array} A one dimensional array containing the matrix in column wise notation. Provides a fall
+     * Converts a two-dimensional array to a one-dimensional Float32Array that can be processed by WebGL.
+     * @param {Array} m A matrix in a two-dimensional array.
+     * @returns {Float32Array} A one-dimensional array containing the matrix in column wise notation. Provides a fall
      * back to the default JavaScript Array if Float32Array is not available.
      */
     toGL: function (m) {
