@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -219,18 +219,11 @@ JXG.extend(
                 co = Math.cos(-radians),
                 si = Math.sin(-radians),
                 bb = el.getBoundingBox(),
-                c1,
-                c2,
-                x1,
-                x2,
-                y1,
-                y2,
-                x1s,
-                x2s,
-                y1s,
-                y2s,
-                dx,
-                dy;
+                c1, c2,
+                x1, x2,
+                y1, y2,
+                x1s, x2s, y1s, y2s,
+                dx, dy;
 
             if (Math.abs(co) > Math.abs(si)) {
                 f /= Math.abs(co);
@@ -278,16 +271,10 @@ JXG.extend(
          */
         updateGradientCircle: function (el, cx, cy, r, fx, fy, fr) {
             var bb = el.getBoundingBox(),
-                c1,
-                c2,
-                cxs,
-                cys,
-                rs,
-                fxs,
-                fys,
-                frs,
-                dx,
-                dy;
+                c1, c2,
+                cxs, cys, rs,
+                fxs, fys, frs,
+                dx, dy;
 
             c1 = new Coords(Const.COORDS_BY_USER, [bb[0], bb[1]], el.board);
             c2 = new Coords(Const.COORDS_BY_USER, [bb[2], bb[3]], el.board);
@@ -308,33 +295,33 @@ JXG.extend(
         updateGradient: function (el) {
             var col,
                 // op,
-                ev_g = Type.evaluate(el.visProp.gradient),
+                ev_g = el.evalVisProp('gradient'),
                 gradient;
 
-            // op = Type.evaluate(el.visProp.fillopacity);
+            // op = el.evalVisProp('fillopacity');
             // op = op > 0 ? op : 0;
-            col = Type.evaluate(el.visProp.fillcolor);
+            col = el.evalVisProp('fillcolor');
 
             if (ev_g === "linear") {
                 gradient = this.updateGradientAngle(
                     el,
-                    Type.evaluate(el.visProp.gradientangle)
+                    el.evalVisProp('gradientangle')
                 );
             } else if (ev_g === "radial") {
                 gradient = this.updateGradientCircle(
                     el,
-                    Type.evaluate(el.visProp.gradientcx),
-                    Type.evaluate(el.visProp.gradientcy),
-                    Type.evaluate(el.visProp.gradientr),
-                    Type.evaluate(el.visProp.gradientfx),
-                    Type.evaluate(el.visProp.gradientfy),
-                    Type.evaluate(el.visProp.gradientfr)
+                    el.evalVisProp('gradientcx'),
+                    el.evalVisProp('gradientcy'),
+                    el.evalVisProp('gradientr'),
+                    el.evalVisProp('gradientfx'),
+                    el.evalVisProp('gradientfy'),
+                    el.evalVisProp('gradientfr')
                 );
             }
-            gradient.addColorStop(Type.evaluate(el.visProp.gradientstartoffset), col);
+            gradient.addColorStop(el.evalVisProp('gradientstartoffset'), col);
             gradient.addColorStop(
-                Type.evaluate(el.visProp.gradientendoffset),
-                Type.evaluate(el.visProp.gradientsecondcolor)
+                el.evalVisProp('gradientendoffset'),
+                el.evalVisProp('gradientsecondcolor')
             );
             return gradient;
         },
@@ -351,14 +338,9 @@ JXG.extend(
          */
         _setColor: function (el, type, targetType) {
             var hasColor = true,
-                ev = el.visProp,
-                hl,
-                sw,
-                rgba,
-                rgbo,
-                c,
-                o,
-                oo,
+                lc, hl, sw,
+                rgba, rgbo,
+                c, o, oo,
                 grad;
 
             type = type || "stroke";
@@ -366,25 +348,19 @@ JXG.extend(
 
             hl = this._getHighlighted(el);
 
-            grad = Type.evaluate(el.visProp.gradient);
-            if (grad === "linear" || grad === "radial") {
-                // TODO: opacity
-                this.context[targetType + "Style"] = this.updateGradient(el);
-                return hasColor;
-            }
-
             // type is equal to 'fill' or 'stroke'
-            rgba = Type.evaluate(ev[hl + type + "color"]);
+            rgba = el.evalVisProp(hl + type + 'color');
             if (rgba !== "none" && rgba !== false) {
-                o = Type.evaluate(ev[hl + type + "opacity"]);
+                o = el.evalVisProp(hl + type + "opacity");
                 o = o > 0 ? o : 0;
 
-                // RGB, not RGBA
                 if (rgba.length !== 9) {
+                    // RGB
                     c = rgba;
                     oo = o;
                     // True RGBA, not RGB
                 } else {
+                    // RGBA
                     rgbo = Color.rgba2rgbo(rgba);
                     c = rgbo[0];
                     oo = o * rgbo[1];
@@ -396,7 +372,14 @@ JXG.extend(
                 hasColor = false;
             }
 
-            sw = parseFloat(Type.evaluate(ev[hl + "strokewidth"]));
+            grad = el.evalVisProp('gradient');
+            if (grad === "linear" || grad === "radial") {
+                this.context.globalAlpha = oo;
+                this.context[targetType + "Style"] = this.updateGradient(el);
+                return hasColor;
+            }
+
+            sw = parseFloat(el.evalVisProp(hl + 'strokewidth'));
             if (type === "stroke" && !isNaN(sw)) {
                 if (sw === 0) {
                     this.context.globalAlpha = 0;
@@ -405,8 +388,9 @@ JXG.extend(
                 }
             }
 
-            if (type === "stroke" && ev.linecap !== undefined && ev.linecap !== "") {
-                this.context.lineCap = ev.linecap;
+            lc = el.evalVisProp('linecap');
+            if (type === "stroke" && lc !== undefined && lc !== "") {
+                this.context.lineCap = lc;
             }
 
             return hasColor;
@@ -419,9 +403,9 @@ JXG.extend(
          */
         _stroke: function (el) {
             var context = this.context,
-                ev_dash = Type.evaluate(el.visProp.dash),
-                ds = Type.evaluate(el.visProp.dashscale),
-                sw = ds ? 0.5 * Type.evaluate(el.visProp.strokewidth) : 1;
+                ev_dash = el.evalVisProp('dash'),
+                ds = el.evalVisProp('dashscale'),
+                sw = ds ? 0.5 * el.evalVisProp('strokewidth') : 1;
 
             context.save();
 
@@ -468,18 +452,16 @@ JXG.extend(
             return rv;
         },
 
-        /* ******************************** *
-         *    Point drawing and updating    *
-         * ******************************** */
+        /* ********* Point related stuff *********** */
 
         // documented in AbstractRenderer
         drawPoint: function (el) {
-            var f = Type.evaluate(el.visProp.face),
-                size = Type.evaluate(el.visProp.size),
+            var f = el.evalVisProp('face'),
+                size = el.evalVisProp('size'),
                 scr = el.coords.scrCoords,
                 sqrt32 = size * Math.sqrt(3) * 0.5,
                 s05 = size * 0.5,
-                stroke05 = parseFloat(Type.evaluate(el.visProp.strokewidth)) / 2.0,
+                stroke05 = parseFloat(el.evalVisProp('strokewidth')) / 2.0,
                 context = this.context;
 
             if (!el.visPropCalc.visible) {
@@ -631,9 +613,7 @@ JXG.extend(
             this.drawPoint(el);
         },
 
-        /* ******************************** *
-         *           Lines                  *
-         * ******************************** */
+        /* ********* Line related stuff *********** */
 
         /**
          * Draws arrows of an element (usually a line) in canvas renderer.
@@ -644,14 +624,9 @@ JXG.extend(
          * @private
          */
         drawArrows: function (el, scr1, scr2, hl, a) {
-            var x1,
-                y1,
-                x2,
-                y2,
-                w0,
-                w,
-                arrowHead,
-                arrowTail,
+            var x1, y1, x2, y2,
+                w, w0,
+                arrowHead, arrowTail,
                 context = this.context,
                 size = 6,
                 type = 1,
@@ -660,19 +635,15 @@ JXG.extend(
                 degree_fa = 1,
                 degree_la = 1,
                 doFill,
-                i,
-                len,
-                d1x,
-                d1y,
-                d2x,
-                d2y,
+                i, len,
+                d1x, d1y,
+                d2x, d2y,
                 last,
-                ang1,
-                ang2,
+                ang1, ang2,
                 ev_fa = a.evFirst,
                 ev_la = a.evLast;
 
-            if (Type.evaluate(el.visProp.strokecolor) !== "none" && (ev_fa || ev_la)) {
+            if (el.evalVisProp('strokecolor') !== "none" && (ev_fa || ev_la)) {
                 if (el.elementClass === Const.OBJECT_CLASS_LINE) {
                     x1 = scr1.scrCoords[1];
                     y1 = scr1.scrCoords[2];
@@ -703,7 +674,7 @@ JXG.extend(
                     }
                 }
 
-                w0 = Type.evaluate(el.visProp[hl + "strokewidth"]);
+                w0 = el.evalVisProp(hl + 'strokewidth');
 
                 if (ev_fa) {
                     size = a.sizeFirst;
@@ -1001,7 +972,7 @@ JXG.extend(
             }
 
             hl = this._getHighlighted(el);
-            w = Type.evaluate(el.visProp[hl + "strokewidth"]);
+            w = el.evalVisProp(hl + 'strokewidth');
             arrowData = this.getArrowHeadData(el, w, hl);
 
             if (arrowData.evFirst || arrowData.evLast) {
@@ -1079,22 +1050,20 @@ JXG.extend(
             this._stroke(ticks);
         },
 
-        /* **************************
-         *    Curves
-         * **************************/
+        /* ********* Curve related stuff *********** */
 
         // documented in AbstractRenderer
         drawCurve: function (el) {
             var hl, w, arrowData;
 
-            if (Type.evaluate(el.visProp.handdrawing)) {
+            if (el.evalVisProp('handdrawing')) {
                 this.updatePathStringBezierPrim(el);
             } else {
                 this.updatePathStringPrim(el);
             }
             if (el.numberPoints > 1) {
                 hl = this._getHighlighted(el);
-                w = Type.evaluate(el.visProp[hl + "strokewidth"]);
+                w = el.evalVisProp(hl + 'strokewidth');
                 arrowData = this.getArrowHeadData(el, w, hl);
                 if (
                     arrowData.evFirst /* && obj.sFirst > 0*/ ||
@@ -1110,9 +1079,7 @@ JXG.extend(
             this.drawCurve(el);
         },
 
-        /* **************************
-         *    Circle related stuff
-         * **************************/
+        /* ********* Circle related stuff *********** */
 
         // documented in AbstractRenderer
         drawEllipse: function (el) {
@@ -1152,15 +1119,11 @@ JXG.extend(
             return this.drawEllipse(el);
         },
 
-        /* **************************
-         *    Polygon
-         * **************************/
+        /* ********* Polygon related stuff *********** */
 
         // nothing here, using AbstractRenderer implementations
 
-        /* **************************
-         *    Text related stuff
-         * **************************/
+        /* ********* Text related stuff *********** */
 
         // Already documented in JXG.AbstractRenderer
         displayCopyright: function (str, fontSize) {
@@ -1177,8 +1140,8 @@ JXG.extend(
 
         // Already documented in JXG.AbstractRenderer
         drawInternalText: function (el) {
-            var ev_fs = Type.evaluate(el.visProp.fontsize),
-                fontUnit = Type.evaluate(el.visProp.fontunit),
+            var ev_fs = el.evalVisProp('fontsize'),
+                fontUnit = el.evalVisProp('fontunit'),
                 ev_ax = el.getAnchorX(),
                 ev_ay = el.getAnchorY(),
                 context = this.context;
@@ -1190,7 +1153,7 @@ JXG.extend(
             ) {
                 context.font = (ev_fs > 0 ? ev_fs : 0) + fontUnit + " Arial";
 
-                this.transformImage(el, el.transformations);
+                this.transformRect(el, el.transformations);
                 if (ev_ax === "left") {
                     context.textAlign = "left";
                 } else if (ev_ax === "right") {
@@ -1219,10 +1182,10 @@ JXG.extend(
         // documented in JXG.AbstractRenderer
         // Only necessary for texts
         setObjectStrokeColor: function (el, color, opacity) {
-            var rgba = Type.evaluate(color),
+            var rgba = color,
                 c,
                 rgbo,
-                o = Type.evaluate(opacity),
+                o = opacity,
                 oo,
                 node;
 
@@ -1248,7 +1211,7 @@ JXG.extend(
                 node = el.rendNode;
                 if (
                     el.elementClass === Const.OBJECT_CLASS_TEXT &&
-                    Type.evaluate(el.visProp.display) === "html"
+                    el.evalVisProp('display') === "html"
                 ) {
                     node.style.color = c;
                     node.style.opacity = oo;
@@ -1259,9 +1222,7 @@ JXG.extend(
             el.visPropOld.strokeopacity = o;
         },
 
-        /* **************************
-         *    Image related stuff
-         * **************************/
+        /* ********* Image related stuff *********** */
 
         // Already documented in JXG.AbstractRenderer
         drawImage: function (el) {
@@ -1278,7 +1239,7 @@ JXG.extend(
         // Already documented in JXG.AbstractRenderer
         updateImage: function (el) {
             var context = this.context,
-                o = Type.evaluate(el.visProp.fillopacity),
+                o = el.evalVisProp('fillopacity'),
                 paintImg = Type.bind(function () {
                     el.imgIsLoaded = true;
                     if (el.size[0] <= 0 || el.size[1] <= 0) {
@@ -1287,8 +1248,8 @@ JXG.extend(
                     context.save();
                     context.globalAlpha = o;
                     // If det(el.transformations)=0, FireFox 3.6. breaks down.
-                    // This is tested in transformImage
-                    this.transformImage(el, el.transformations);
+                    // This is tested in transformRect
+                    this.transformRect(el, el.transformations);
                     context.drawImage(
                         el.rendNode,
                         el.coords.scrCoords[1],
@@ -1309,7 +1270,7 @@ JXG.extend(
         },
 
         // Already documented in JXG.AbstractRenderer
-        transformImage: function (el, t) {
+        transformRect: function (el, t) {
             var m, s, cx, cy, node,
                 len = t.length,
                 ctx = this.context;
@@ -1323,11 +1284,11 @@ JXG.extend(
                         node.style.transform = s;
                         cx = -el.coords.scrCoords[1];
                         cy = -el.coords.scrCoords[2];
-                        switch (Type.evaluate(el.visProp.anchorx)) {
+                        switch (el.evalVisProp('anchorx')) {
                             case 'right': cx += el.size[0]; break;
                             case 'middle': cx += el.size[0] * 0.5; break;
                         }
-                        switch (Type.evaluate(el.visProp.anchory)) {
+                        switch (el.evalVisProp('anchory')) {
                             case 'bottom': cy += el.size[1]; break;
                             case 'middle': cy += el.size[1] * 0.5; break;
                         }
@@ -1345,7 +1306,7 @@ JXG.extend(
         updateImageURL: function (el) {
             var url;
 
-            url = Type.evaluate(el.url);
+            url = el.eval(el.url);
             if (el._src !== url) {
                 el.imgIsLoaded = false;
                 el.rendNode.src = url;
@@ -1356,9 +1317,7 @@ JXG.extend(
             return false;
         },
 
-        /* **************************
-         * Render primitive objects
-         * **************************/
+        /* ********* Render primitive objects *********** */
 
         // documented in AbstractRenderer
         remove: function (shape) {
@@ -1454,25 +1413,21 @@ JXG.extend(
                 }
             }
             context.lineCap = "round";
+            context.lineJoin = "round";
             this._fill(el);
             this._stroke(el);
         },
 
         // Already documented in JXG.AbstractRenderer
         updatePathStringBezierPrim: function (el) {
-            var i,
-                j,
-                k,
-                scr,
-                lx,
-                ly,
-                len,
+            var i, j, k,
+                scr, lx, ly, len,
                 symbm = "M",
                 symbl = "C",
                 nextSymb = symbm,
                 maxSize = 5000.0,
-                f = Type.evaluate(el.visProp.strokewidth),
-                isNoPlot = Type.evaluate(el.visProp.curvetype) !== "plot",
+                f = el.evalVisProp('strokewidth'),
+                isNoPlot = el.evalVisProp('curvetype') !== "plot",
                 context = this.context;
 
             if (el.numberPoints <= 0) {
@@ -1528,6 +1483,7 @@ JXG.extend(
                 }
             }
             context.lineCap = "round";
+            context.lineJoin = "round";
             this._fill(el);
             this._stroke(el);
         },
@@ -1571,7 +1527,7 @@ JXG.extend(
             }
         },
 
-        // **************************  Set Attributes *************************
+        /* ********* Set attributes *********** */
 
         // Already documented in JXG.AbstractRenderer
         display: function (el, val) {
@@ -1608,10 +1564,10 @@ JXG.extend(
             // var // col,
             //     op;
 
-            // op = Type.evaluate(el.visProp.fillopacity);
+            // op = el.evalVisProp('fillopacity');
             // op = op > 0 ? op : 0;
 
-            // col = Type.evaluate(el.visProp.fillcolor);
+            // col = el.evalVisProp('fillcolor');
         },
 
         // documented in AbstractRenderer
@@ -1631,7 +1587,7 @@ JXG.extend(
         highlight: function (obj) {
             if (
                 obj.elementClass === Const.OBJECT_CLASS_TEXT &&
-                Type.evaluate(obj.visProp.display) === "html"
+                obj.evalVisProp('display') === "html"
             ) {
                 this.updateTextStyle(obj, true);
             } else {
@@ -1647,7 +1603,7 @@ JXG.extend(
         noHighlight: function (obj) {
             if (
                 obj.elementClass === Const.OBJECT_CLASS_TEXT &&
-                Type.evaluate(obj.visProp.display) === "html"
+                obj.evalVisProp('display') === "html"
             ) {
                 this.updateTextStyle(obj, false);
             } else {
@@ -1659,9 +1615,7 @@ JXG.extend(
             return this;
         },
 
-        /* **************************
-         * renderer control
-         * **************************/
+        /* ********* Renderer control *********** */
 
         // documented in AbstractRenderer
         suspendRedraw: function (board) {
