@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -184,6 +184,7 @@ var simpleColors = {
         thistle: "d8bfd8",
         tomato: "ff6347",
         turquoise: "40e0d0",
+        venetianred: "ae181e",
         violet: "ee82ee",
         violetred: "d02090",
         wheat: "f5deb3",
@@ -486,11 +487,11 @@ JXG.hsv2rgb = function (H, S, V) {
  * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
- * expects the parameters ag and ab.
+ * expects the parameters ag and ab. See <a href="https://www.had2know.org/technology/hsv-rgb-conversion-formula-calculator.html">https://www.had2know.org/technology/hsv-rgb-conversion-formula-calculator.html</a>.
  * @param {Number} ag
  * @param {Number} ab
  * @returns {Array} Contains the h, s, and v value in this order.
- * @see https://www.had2know.org/technology/hsv-rgb-conversion-formula-calculator.html
+ *
  */
 JXG.rgb2hsv = function (color, ag, ab) {
     var r, g, b, fr, fg, fb, fmax, fmin, h, s, v, max, min;
