@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -396,7 +396,7 @@ JXG.extend(
                 deps = {};
 
             for (i = 0; i < n; i++) {
-                f[i] = JXG.createFunction(param[i], board);
+                f[i] = this.createFunction(param[i], board);
                 for (e in f[i].deps) {
                     deps[e] = f[i].deps;
                 }
@@ -438,15 +438,15 @@ JXG.extend(
             } else if (this.isFunction(term)) {
                 f = term;
                 f.deps = (this.isObject(term.deps)) ? term.deps : {};
-            } else if (this.isNumber(term)) {
+            } else if (this.isNumber(term) || this.isArray(term)) {
                 /** @ignore */
                 f = function () { return term; };
                 f.deps = {};
-            // } else if (this.isString(term)) {
-            //     // In case of string function like fontsize
-            //     /** @ignore */
-            //     f = function () { return term; };
-            //     f.deps = {};
+                // } else if (this.isString(term)) {
+                //     // In case of string function like fontsize
+                //     /** @ignore */
+                //     f = function () { return term; };
+                //     f.deps = {};
             }
 
             if (f !== null) {
@@ -580,9 +580,19 @@ JXG.extend(
                     );
                 }
 
-                if (this.isArray(parents[i]) && parents[i].length > 1) {
+                if (this.isArray(parents[i]) && parents[i].length > 0 && parents[i].every((x)=>this.isArray(x) && this.isNumber(x[0]))) {
+                    // Testing for array-of-arrays-of-numbers, like [[1,2,3],[2,3,4]]
+                    for (j = 0; j < parents[i].length; j++) {
+                        points.push(view.create("point3d", parents[i][j], attr));;
+                        points[points.length - 1]._is_new = true;
+                    }
+                } else if (this.isArray(parents[i]) &&  parents[i].every((x)=> this.isNumber(x) || this.isFunction(x))) {
+                    // Single array [1,2,3]
                     points.push(view.create("point3d", parents[i], attr));
                     points[points.length - 1]._is_new = true;
+
+                } else if (this.isPoint3D(parents[i])) {
+                    points.push(parents[i]);
                 } else if (this.isFunction(parents[i])) {
                     val = parents[i]();
                     if (this.isArray(val) && val.length > 1) {
@@ -1103,7 +1113,7 @@ JXG.extend(
          * @param {Object} obj1
          * @param {Object} obj2
          * @returns {Object}
-         * @see JXG#mergeAttr
+         * @see JXG.mergeAttr
          *
          * @example
          * JXG.Options = JXG.merge(JXG.Options, {
@@ -1275,7 +1285,7 @@ JXG.extend(
          * @param {Boolean} [toLower=true] If true the keys are converted to lower case.
          * @param {Boolean} [ignoreUndefinedSpecials=false] If true the values in special that are undefined are not used.
          *
-         * @see JXG#merge
+         * @see JXG.merge
          *
          */
         mergeAttr: function (attr, special, toLower, ignoreUndefinedSpecials) {
@@ -1287,7 +1297,6 @@ JXG.extend(
             for (e in special) {
                 if (special.hasOwnProperty(e)) {
                     e2 = (toLower) ? e.toLowerCase(): e;
-
                     // Key already exists, but not in lower case
                     if (e2 !== e && attr.hasOwnProperty(e)) {
                         if (attr.hasOwnProperty(e2)) {
@@ -1490,6 +1499,59 @@ JXG.extend(
             }
         },
 
+        /**
+         * Create a stripped down version of a JSXGraph element for cloning to the background.
+         * Used in {JXG.GeometryElement#cloneToBackground} for creating traces.
+         *
+         * @param {JXG.GeometryElement} el Element to be cloned
+         * @returns Object Cloned element
+         * @private
+         */
+        getCloneObject: function(el) {
+            var obj, key,
+                copy = {};
+
+            copy.id = el.id + "T" + el.numTraces;
+            el.numTraces += 1;
+
+            copy.coords = el.coords;
+            obj = this.deepCopy(el.visProp, el.visProp.traceattributes, true);
+            copy.visProp = {};
+            for (key in obj) {
+                if (obj.hasOwnProperty(key)) {
+                    if (
+                        key.indexOf('aria') !== 0 &&
+                        key.indexOf('highlight') !== 0 &&
+                        key.indexOf('attractor') !== 0 &&
+                        key !== 'label' &&
+                        key !== 'needsregularupdate' &&
+                        key !== 'infoboxdigits'
+                    ) {
+                        copy.visProp[key] = el.eval(obj[key]);
+                    }
+                }
+            }
+            copy.evalVisProp = function(val) {
+                return copy.visProp[val];
+            };
+            copy.eval = function(val) {
+                return val;
+            };
+
+            copy.visProp.layer = el.board.options.layer.trace;
+            copy.visProp.tabindex = null;
+            copy.visProp.highlight = false;
+            copy.board = el.board;
+            copy.elementClass = el.elementClass;
+
+            this.clearVisPropOld(copy);
+            copy.visPropCalc = {
+                visible: el.evalVisProp('visible')
+            };
+
+            return copy;
+        },
+
         /**
          * Converts a JavaScript object into a JSON string.
          * @param {Object} obj A JavaScript object, functions will be ignored.
@@ -1746,7 +1808,7 @@ JXG.extend(
          * @param {Boolean} [useTeX=false]
          * @param {Number} [order=0.001]
          * @returns {String}
-         * @see JXG.Math#decToFraction
+         * @see JXG.Math.decToFraction
          */
         toFraction: function (x, useTeX, order) {
             var arr = Mat.decToFraction(x, order),
@@ -1845,6 +1907,8 @@ JXG.extend(
          * <p>
          * This function is meanwhile superseded by stack_jxg.stack2jsxgraph.
          *
+         * @deprecated
+         *
          * @example
          * console.log( JXG.stack2jsxgraph("%e**x") );
          * // Output:
